<?php
// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

/**
 * 注册文章子菜单
 */
function jefrss_register_articles_menu() {
    add_submenu_page(
        'jefrss-simple',
        '文章',
        '文章',
        'manage_options',
        'jefrss-simple-articles',
        'jefrss_simple_articles_page'
    );
    
    // 添加隐藏的文章详情页面
    add_submenu_page(
        null, // 不显示在菜单中
        '文章详情',
        '文章详情',
        'manage_options',
        'jefrss-simple-article',
        'jefrss_simple_article_page'
    );
}
add_action('admin_menu', 'jefrss_register_articles_menu', 20); // 优先级设为20，确保在主菜单之后添加

/**
 * 获取所有文章并支持分页
 * 
 * @param int $page 当前页码
 * @param int $per_page 每页显示数量
 * @param string $site_filter 站点筛选
 * @return array 文章数据和分页信息
 */
function jefrss_get_all_articles($page = 1, $per_page = 20, $site_filter = '') {
    $feeds = get_option('jefrss_feeds', array());
    $articles = array();
    
    foreach ($feeds as $url => $feed) {
        if (!empty($site_filter) && $feed['name'] !== $site_filter) {
            continue;
        }
        
        if (isset($feed['items']) && is_array($feed['items'])) {
            foreach ($feed['items'] as $item) {
                // 添加站点信息到文章
                $item['site_name'] = $feed['name'];
                $item['site_url'] = $url;
                $item['site_icon'] = isset($feed['icon']) ? $feed['icon'] : '';
                $articles[] = $item;
            }
        }
    }
    
    // 按发布时间排序（最新的在前）
    usort($articles, function($a, $b) {
        return strtotime($b['date']) - strtotime($a['date']);
    });
    
    // 计算分页
    $total = count($articles);
    $total_pages = ceil($total / $per_page);
    $page = max(1, min($page, $total_pages > 0 ? $total_pages : 1));
    $offset = ($page - 1) * $per_page;
    $paged_articles = array_slice($articles, $offset, $per_page);
    
    return array(
        'articles' => $paged_articles,
        'pagination' => array(
            'total' => $total,
            'per_page' => $per_page,
            'current_page' => $page,
            'total_pages' => $total_pages
        )
    );
}

/**
 * 文章列表页面
 */
function jefrss_simple_articles_page() {
    // 获取当前页码和筛选条件
    $current_page = isset($_GET['paged']) ? intval($_GET['paged']) : 1;
    $site_filter = isset($_GET['site']) ? sanitize_text_field($_GET['site']) : '';
    
    // 获取文章数据
    $articles_data = jefrss_get_all_articles($current_page, 20, $site_filter);
    $articles = $articles_data['articles'];
    $pagination = $articles_data['pagination'];
    
    // 获取所有站点名称（用于筛选）
    $feeds = get_option('jefrss_feeds', array());
    $sites = array();
    foreach ($feeds as $feed) {
        $sites[] = $feed['name'];
    }
    $sites = array_unique($sites);
    sort($sites); // 按字母顺序排序
    
    // 输出CSS样式
    jefrss_articles_styles();
    
    // 渲染页面
    ?>
    <div class="wrap jefrss-articles">
        <h1>订阅文章</h1>
        
        <!-- 筛选表单 -->
        <div class="tablenav top">
            <form method="get" action="">
                <input type="hidden" name="page" value="jefrss-simple-articles">
                <select name="site">
                    <option value="">所有站点</option>
                    <?php foreach ($sites as $site): ?>
                    <option value="<?php echo esc_attr($site); ?>" <?php selected($site_filter, $site); ?>><?php echo esc_html($site); ?></option>
                    <?php endforeach; ?>
                </select>
                <input type="submit" class="button" value="筛选">
                <?php if (!empty($site_filter)): ?>
                <a href="<?php echo esc_url(admin_url('admin.php?page=jefrss-simple-articles')); ?>" class="button">清除筛选</a>
                <?php endif; ?>
            </form>
        </div>
        
        <!-- 文章列表 -->
        <table class="wp-list-table widefat fixed striped">
            <thead>
                <tr>
                    <th width="20%">站点</th>
                    <th width="30%">标题</th>
                    <th>描述</th>
                    <th width="15%">发布时间</th>
                    <th width="10%">操作</th>
                </tr>
            </thead>
            <tbody>
                <?php if (empty($articles)): ?>
                <tr>
                    <td colspan="5">暂无文章</td>
                </tr>
                <?php else: ?>
                <?php foreach ($articles as $index => $article): ?>
                <tr>
                    <td>
                        <?php if (!empty($article['site_icon'])): ?>
                        <img src="<?php echo esc_url($article['site_icon']); ?>" width="16" height="16" style="vertical-align: middle; margin-right: 5px;">
                        <?php endif; ?>
                        <?php echo esc_html($article['site_name']); ?>
                    </td>
                    <td><?php echo esc_html($article['title']); ?></td>
                    <td><?php echo wp_trim_words(wp_strip_all_tags($article['description']), 20); ?></td>
                    <td><?php 
                        // 将 GMT 时间转换为本地时间
                        $local_date = get_date_from_gmt($article['date']);
                        echo esc_html(date('Y-m-d H:i', strtotime($local_date))); 
                    ?></td>
                    <td>
                        <a href="<?php echo esc_url(admin_url('admin.php?page=jefrss-simple-article&id=' . $index . '&paged=' . $current_page . '&site=' . urlencode($site_filter))); ?>" class="button button-small">查看</a>
                        <a href="<?php echo esc_url($article['link']); ?>" target="_blank" class="button button-small">原文</a>
                    </td>
                </tr>
                <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
        
        <!-- 分页 -->
        <?php if ($pagination['total_pages'] > 1): ?>
        <div class="tablenav bottom">
            <div class="tablenav-pages">
                <span class="displaying-num"><?php echo esc_html($pagination['total']); ?> 篇文章</span>
                <span class="pagination-links">
                    <?php
                    // 构建分页链接
                    $page_links = paginate_links(array(
                        'base' => add_query_arg('paged', '%#%'),
                        'format' => '',
                        'prev_text' => '&laquo;',
                        'next_text' => '&raquo;',
                        'total' => $pagination['total_pages'],
                        'current' => $pagination['current_page'],
                        'add_args' => array('site' => $site_filter)
                    ));
                    echo $page_links;
                    ?>
                </span>
            </div>
        </div>
        <?php endif; ?>
    </div>
    <?php
}

/**
 * 文章详情页面
 */
function jefrss_simple_article_page() {
    // 获取文章ID和分页信息
    $article_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
    $current_page = isset($_GET['paged']) ? intval($_GET['paged']) : 1;
    $site_filter = isset($_GET['site']) ? sanitize_text_field($_GET['site']) : '';
    
    // 获取文章数据
    $articles_data = jefrss_get_all_articles($current_page, 20, $site_filter);
    $articles = $articles_data['articles'];
    
    if (!isset($articles[$article_id])) {
        wp_die('文章不存在');
    }
    
    $article = $articles[$article_id];
    
    ?>
    <div class="wrap jefrss-article-page">
        <div class="article-container">
            <!-- 主内容区 -->
            <div class="article-main">
                <h1><?php echo esc_html($article['title']); ?></h1>
                
                <div class="article-meta">
                    <?php if (!empty($article['site_icon'])): ?>
                    <img src="<?php echo esc_url($article['site_icon']); ?>" alt="" class="site-icon">
                    <?php endif; ?>
                    <span class="site-name">
                        <a href="<?php echo esc_url($article['site_url']); ?>" target="_blank">
                            <?php echo esc_html($article['site_name']); ?>
                        </a>
                    </span>
                    <span class="article-date">
                        <?php 
                            $local_date = get_date_from_gmt($article['date']);
                            echo esc_html(date('Y-m-d H:i:s', strtotime($local_date))); 
                        ?>
                    </span>
                </div>
                
                <div class="article-content">
                    <?php echo wp_kses_post($article['content']); ?>
                </div>
                
                <div class="article-actions">
                    <a href="<?php echo esc_url($article['link']); ?>" target="_blank" class="button">
                        查看原文
                    </a>
                    <a href="<?php echo esc_url(admin_url('admin.php?page=jefrss-simple-articles&paged=' . $current_page . '&site=' . urlencode($site_filter))); ?>" class="button">
                        返回列表
                    </a>
                </div>
            </div>
            
            <!-- 右侧边栏 -->
            <div class="article-sidebar">
                <h3>最新文章</h3>
                <ul class="recent-articles">
                    <?php foreach (array_slice($articles, 0, 30) as $index => $recent): ?>
                        <li class="<?php echo $index === $article_id ? 'current' : ''; ?>">
                            <a href="<?php echo esc_url(add_query_arg('id', $index, remove_query_arg('paged'))); ?>">
                                <?php echo esc_html($recent['title']); ?>
                                <span class="article-site"><?php echo esc_html($recent['site_name']); ?></span>
                            </a>
                        </li>
                    <?php endforeach; ?>
                </ul>
            </div>
        </div>
    </div>
    
    <style>
    /* 阅读页面样式 */
    .jefrss-article-page {
        max-width: 1200px;
        margin: 20px auto;
        padding: 0 20px;
    }
    
    .article-container {
        display: flex;
        gap: 30px;
        background: #fff;
        border-radius: 8px;
        box-shadow: 0 1px 3px rgba(0,0,0,0.1);
    }
    
    /* 主内容区样式 */
    .article-main {
        flex: 1;
        max-width: 800px;
        padding: 40px;
    }
    
    .article-main h1 {
        font-size: 28px;
        line-height: 1.4;
        margin: 0 0 20px;
        color: #1d2327;
        font-weight: 500;
    }
    
    .article-meta {
        display: flex;
        align-items: center;
        gap: 10px;
        margin-bottom: 30px;
        padding-bottom: 20px;
        border-bottom: 1px solid #f0f0f1;
        color: #646970;
        font-size: 15px;
    }
    
    .article-meta .site-icon {
        width: 20px;
        height: 20px;
        border-radius: 4px;
    }
    
    .article-content {
        font-size: 18px;
        line-height: 1.9;
        color: #2c3338;
    }
    
    .jefrss-article-page .article-content p {
        margin-bottom: 1.5em;
        font-size: 18px !important;
        line-height: 1.9 !important;
        margin-top: 0;
    }
    
    /* 确保其他内容元素也使用正确的字体大小 */
    .jefrss-article-page .article-content ul,
    .jefrss-article-page .article-content ol,
    .jefrss-article-page .article-content li,
    .jefrss-article-page .article-content blockquote {
        font-size: 18px !important;
        line-height: 1.9 !important;
    }
    
    .article-content img {
        max-width: 100%;
        height: auto;
        margin: 1em 0;
    }
    
    /* 覆盖WordPress后台默认样式 */
    #wpcontent .jefrss-article-page {
        font-size: 18px;
    }
    
    #wpcontent .jefrss-article-page p {
        font-size: 15px !important;
    }
    
    .article-actions {
        margin-top: 40px;
        padding-top: 20px;
        border-top: 1px solid #f0f0f1;
    }
    
    /* 右侧边栏样式 */
    .article-sidebar {
        width: 300px;
        padding: 30px;
        background: #fff;
        border-left: 1px solid #f0f0f1;
    }
    
    .article-sidebar h3 {
        margin: 0 0 20px;
        font-size: 18px;
        color: #1d2327;
        padding-bottom: 15px;
        border-bottom: 2px solid #f0f0f1;
    }
    
    .recent-articles {
        margin: 0;
        padding: 0;
        list-style: none;
    }
    
    .recent-articles li {
        margin-bottom: 20px;
        padding: 12px 15px;
        border-bottom: 1px solid #f0f0f1;
        transition: all 0.2s ease;
        border-radius: 6px;
    }
    
    .recent-articles li:last-child {
        margin-bottom: 0;
        padding-bottom: 0;
        border-bottom: none;
    }
    
    .recent-articles li:hover {
        background: #f8f9fa;
    }
    
    .recent-articles li.current {
        background: #f0f7fc !important;
        border-left: 3px solid #2271b1;
    }
    
    .recent-articles a {
        display: block;
        color: #2c3338;
        text-decoration: none;
        font-size: 15px;
        line-height: 1.4;
    }
    
    .recent-articles a:hover {
        color: #2271b1;
    }
    
    .recent-articles .article-site {
        display: block;
        font-size: 13px;
        color: #646970;
        margin-top: 8px;
    }
    
    /* 响应式布局 */
    @media screen and (max-width: 782px) {
        .article-container {
            flex-direction: column;
        }
    
        .article-main {
            padding: 20px;
        }
    
        .article-sidebar {
            width: 100%;
            border-left: none;
            border-top: 1px solid #f0f0f1;
        }
    }
    </style>
    <?php
}

/**
 * 输出文章模块的CSS样式
 */
function jefrss_articles_styles() {
    ?>
    <style type="text/css">
    /* 文章列表样式 */
    .jefrss-articles .tablenav {
        margin: 15px 0;
    }
    
    .jefrss-articles .tablenav select {
        margin-right: 5px;
    }
    
    /* 文章详情样式 */
    .jefrss-articles .article-meta {
        color: #666;
        margin-bottom: 20px;
        padding-bottom: 10px;
        border-bottom: 1px solid #eee;
    }
    
    .jefrss-articles .article-content {
        line-height: 1.6;
        margin-bottom: 20px;
        background: #fff;
        padding: 20px;
        border-radius: 5px;
        box-shadow: 0 1px 3px rgba(0,0,0,0.1);
    }
    
    .jefrss-articles .article-content img {
        max-width: 100%;
        height: auto;
    }
    
    .jefrss-articles .article-content a {
        color: #0073aa;
        text-decoration: none;
    }
    
    .jefrss-articles .article-content a:hover {
        color: #00a0d2;
        text-decoration: underline;
    }
    
    /* 代码块格式化 */
    .jefrss-articles .article-content pre,
    .jefrss-articles .article-content code {
        background: #f5f5f5;
        border: 1px solid #ddd;
        border-radius: 3px;
        padding: 10px;
        font-family: monospace;
        overflow: auto;
        max-width: 100%;
    }
    
    .jefrss-articles .article-content pre {
        margin: 15px 0;
    }
    
    .jefrss-articles .article-content code {
        padding: 2px 5px;
    }
    
    /* 分页样式 */
    .jefrss-articles .pagination-links .page-numbers {
        display: inline-block;
        min-width: 28px;
        padding: 0 5px;
        height: 28px;
        margin: 0 3px;
        text-align: center;
        line-height: 28px;
        background: #f7f7f7;
        border: 1px solid #ddd;
        border-radius: 3px;
        text-decoration: none;
    }
    
    .jefrss-articles .pagination-links .page-numbers.current {
        background: #0073aa;
        border-color: #0073aa;
        color: #fff;
    }
    
    .jefrss-articles .article-actions {
        margin-top: 20px;
    }
    </style>
    <?php
}
