<?php
// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

/**
 * RSS Manager 类
 */
class Jefrss_Simple_Manager {
    private static $instance = null;
    
    /**
     * 获取单例
     */
    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }
    
    /**
     * 抓取单个源
     */
    public function fetch_feed($url) {
        $result = jefrss_simple_fetch_feed($url);
        
        if ($result['success']) {
            return true;
        } else {
            return new WP_Error('fetch_failed', $result['message']);
        }
    }
    
    /**
     * 添加订阅源
     */
    public function add_feed($url, $name = '') {
        // 在任何输出之前启动输出缓冲
        if (!headers_sent()) {
            ob_start();
        }
        
        try {
            // 验证URL格式
            if (!filter_var($url, FILTER_VALIDATE_URL)) {
                throw new Exception('无效的URL格式');
            }
            
            // 尝试获取feed
            if (!function_exists('fetch_feed')) {
                include_once(ABSPATH . WPINC . '/feed.php');
            }
            
            $feed = fetch_feed($url);
            if (is_wp_error($feed)) {
                throw new Exception('无法获取RSS源: ' . $feed->get_error_message());
            }
            
            // 如果没有提供名称，使用feed标题
            if (empty($name)) {
                $name = $feed->get_title();
                if (empty($name)) {
                    $name = parse_url($url, PHP_URL_HOST);
                }
            }
            
            // 获取全局设置
            $fetch_interval = get_option('jefrss_fetch_interval', 180);
            $fetch_count = get_option('jefrss_fetch_count', 3);
            
            // 保存feed时只传入URL和名称,使用全局设置
            $result = jefrss_simple_save_feed($url, $name);
            
            // 清除并关闭输出缓冲
            if (ob_get_level()) {
                ob_end_clean();
            }
            
            if ($result['success']) {
                // 设置成功消息
                add_settings_error(
                    'jefrss_messages',
                    'feed_added',
                    sprintf('成功添加订阅源: %s', $name),
                    'success'
                );
                
                // 重定向回列表页
                wp_redirect(admin_url('admin.php?page=jefrss-simple-sites&message=added'));
                exit;
            } else {
                throw new Exception($result['message']);
            }
            
        } catch (Exception $e) {
            // 清除并关闭输出缓冲
            if (ob_get_level()) {
                ob_end_clean();
            }
            
            // 设置错误消息
            add_settings_error(
                'jefrss_messages',
                'feed_add_error',
                $e->getMessage(),
                'error'
            );
            
            // 重定向回列表页并显示错误
            wp_redirect(admin_url('admin.php?page=jefrss-simple-sites&error=1'));
            exit;
        }
    }
    
    /**
     * 删除订阅源
     */
    public function delete_feed($url) {
        // 检查用户权限
        if (!current_user_can('manage_options')) {
            wp_die('您没有足够的权限执行此操作。');
        }
        
        // 验证 nonce
        if (!isset($_REQUEST['_wpnonce']) || !wp_verify_nonce($_REQUEST['_wpnonce'], 'jefrss_feed_action')) {
            wp_die('安全验证失败');
        }
        
        try {
            $feeds = $this->get_feeds();
            
            if (!isset($feeds[$url])) {
                throw new Exception('订阅不存在');
            }
            
            // 删除图标文件
            $icon_file = JEFRSS_ICONS_DIR . md5(jefrss_simple_get_actual_domain($url)) . '.png';
            if (file_exists($icon_file)) {
                @unlink($icon_file);
            }
            
            // 删除订阅数据
            unset($feeds[$url]);
            
            // 保存到数据库
            if (update_option('jefrss_feeds', $feeds)) {
                jefrss_add_log('订阅源删除成功: ' . $url);
                
                // 使用 JavaScript 重定向，而不是 HTTP 头
                ?>
                <script>
                window.location.href = '<?php echo admin_url('admin.php?page=jefrss-simple-sites&message=deleted'); ?>';
                </script>
                <?php
                exit;
            }
            
            throw new Exception('删除失败');
            
        } catch (Exception $e) {
            jefrss_add_log('删除订阅源失败: ' . $url . ' - ' . $e->getMessage());
            
            // 使用 JavaScript 重定向，而不是 HTTP 头
            ?>
            <script>
            window.location.href = '<?php echo admin_url('admin.php?page=jefrss-simple-sites&error=1'); ?>';
            </script>
            <?php
            exit;
        }
    }
    
    /**
     * 保存订阅源
     */
    public function save_feed($url, $name = '') {
        // 移除interval和fetch_count参数
        $result = jefrss_simple_save_feed($url, $name);
        
        // 保存通知消息到临时选项
        if ($result['success']) {
            set_transient('jefrss_admin_notice', array(
                'message' => sprintf('成功添加订阅源：%s', $name ?: $url),
                'type' => 'success'
            ), 30);
        } else {
            set_transient('jefrss_admin_notice', array(
                'message' => $result['message'],
                'type' => 'error'
            ), 30);
        }
        
        return $result;
    }
    
    /**
     * 批量保存订阅源
     */
    public function batch_save_feeds($feeds_data) {
        $result = jefrss_simple_batch_save_feeds($feeds_data);
        
        // 添加批量操作的通知
        if (!empty($result['success'])) {
            add_settings_error(
                'jefrss_messages',
                'feeds_added',
                sprintf('成功添加 %d 个订阅源', count($result['success'])),
                'success'
            );
        }
        
        if (!empty($result['duplicates'])) {
            add_settings_error(
                'jefrss_messages',
                'feeds_duplicate',
                sprintf('发现 %d 个重复的订阅源', count($result['duplicates'])),
                'warning'
            );
        }
        
        if (!empty($result['failed'])) {
            foreach ($result['failed'] as $fail) {
                add_settings_error(
                    'jefrss_messages',
                    'feed_error',
                    sprintf('添加失败：%s - %s', $fail['url'], $fail['message']),
                    'error'
                );
            }
        }
        
        return $result;
    }
    
    /**
     * 记录系统事件
     * @param string $event 事件描述
     * @param string $type 事件类型 (info/warning/error)
     */
    public function log_system_event($event, $type = 'info') {
        $message = sprintf('[%s] %s', strtoupper($type), $event);
        jefrss_add_log($message);
        
        return array(
            'success' => true,
            'message' => $message
        );
    }
    
    /**
     * 获取所有订阅源
     */
    public function get_feeds() {
        return jefrss_simple_get_feeds();
    }
    
    /**
     * 编辑订阅源
     */
    public function edit_feed($old_url, $new_url, $name) {
        // 移除interval和fetch_count参数
        return jefrss_simple_save_feed($new_url, $name, true);
    }
}