<?php
// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

/**
 * 保存 RSS 订阅数据
 */
function jefrss_simple_save_feed($url, $name = '', $is_update = false) {
    // 在任何输出之前启动输出缓冲
    if (!headers_sent()) {
        ob_start();
    }
    
    try {
        // 验证URL基本格式
        if (!filter_var($url, FILTER_VALIDATE_URL)) {
            throw new Exception('无效的URL格式');
        }
        
        $feeds = jefrss_simple_get_feeds();
        
        // 检查是否已存在（仅在新增时检查）
        if (!$is_update && isset($feeds[$url])) {
            jefrss_add_log('订阅源已存在: ' . $url);
            
            // 清除并关闭输出缓冲
            if (ob_get_level()) {
                ob_end_clean();
            }
            
            return array(
                'success' => false,
                'message' => '该订阅地址已存在'
            );
        }
        
        // 如果未提供站点名称,使用域名作为默认名称
        if (empty($name)) {
            $name = jefrss_simple_get_actual_domain($url);
        }
        
        // 获取全局设置
        $fetch_interval = get_option('jefrss_fetch_interval', 180);
        $fetch_count = get_option('jefrss_fetch_count', 3);
        
        // 保存或更新feed信息
        $feeds[$url] = array(
            'name' => $name,
            'url' => $url,
            'interval' => $fetch_interval,  // 使用全局间隔设置
            'fetch_count' => $fetch_count,  // 使用全局抓取数量设置
            'last_fetch' => isset($feeds[$url]['last_fetch']) ? $feeds[$url]['last_fetch'] : 0,
            'icon' => $icon_url,
            'icon_status' => 'completed',
            'items' => isset($feeds[$url]['items']) ? $feeds[$url]['items'] : array()
        );
        
        // 保存到数据库
        update_option('jefrss_feeds', $feeds);
        
        return array(
            'success' => true,
            'message' => '保存成功'
        );
    } catch (Exception $e) {
        return array(
            'success' => false,
            'message' => $e->getMessage()
        );
    }
}

/**
 * 批量添加订阅
 */
function jefrss_simple_batch_save_feeds($feeds_data) {
    $results = array(
        'success' => array(),
        'failed' => array(),
        'duplicates' => array() // 新增重复项统计
    );
    
    $feeds = jefrss_simple_get_feeds();
    
    foreach ($feeds_data as $feed) {
        if (empty($feed['url'])) {
            continue;
        }
        
        $url = $feed['url'];
        
        // 检查是否已存在
        if (isset($feeds[$url])) {
            $results['duplicates'][] = $url; // 记录重复项
            $results['failed'][] = array(
                'url' => $url,
                'message' => '该订阅地址已存在'
            );
            continue;
        }
        
        $result = jefrss_simple_save_feed(
            $url,
            isset($feed['name']) ? $feed['name'] : '',
            isset($feed['interval']) ? $feed['interval'] : 60,
            isset($feed['fetch_count']) ? $feed['fetch_count'] : 1
        );
        
        if ($result['success']) {
            $results['success'][] = $url;
        } else {
            $results['failed'][] = array(
                'url' => $url,
                'message' => $result['message']
            );
        }
    }
    
    // 添加重复项数量
    $results['duplicate_count'] = count($results['duplicates']);
    
    return $results;
}

/**
 * 获取所有订阅源
 */
function jefrss_simple_get_feeds() {
    // 从数据库获取
    return get_option('jefrss_feeds', array());
}

/**
 * 获取实际的域名
 * 处理二级域名和主域名的情况
 */
function jefrss_simple_get_actual_domain($url) {
    $domain = parse_url($url, PHP_URL_HOST);
    if (empty($domain)) {
        return '';
    }

    // 移除 www. 前缀
    $domain = preg_replace('/^www\./i', '', $domain);

    // 分割域名部分
    $parts = explode('.', $domain);
    $count = count($parts);

    // 处理不同情况
    if ($count >= 3) {
        // 可能是二级域名 (blog.example.com)
        // 检查是否是常见的二级域名服务
        $common_tlds = array(
            'com.cn', 'org.cn', 'net.cn', 'gov.cn', // 中国特殊域名
            'co.uk', 'co.jp', 'co.kr', 'com.au',    // 其他国家特殊域名
            'com.tw', 'com.hk', 'com.sg'            // 其他亚洲地区域名
        );
        
        // 检查最后两部分是否匹配常见的特殊顶级域名
        $last_two = $parts[$count-2] . '.' . $parts[$count-1];
        if (in_array($last_two, $common_tlds)) {
            // 如果是特殊顶级域名，返回完整的三段
            return $parts[$count-3] . '.' . $last_two;
        } else {
            // 否则认为是二级域名，返回完整域名
            return $domain;
        }
    } else if ($count == 2) {
        // 标准域名 (example.com)
        return $domain;
    }

    // 其他情况返回原始域名
    return $domain;
}

/**
 * 获取站点图标
 */
function jefrss_simple_get_site_icon($url) {
    // 解析URL获取域名
    $parsed_url = parse_url($url);
    $domain = isset($parsed_url['host']) ? $parsed_url['host'] : '';
    
    if (empty($domain)) {
        return plugins_url('icons/default.png', dirname(__FILE__));
    }
    
    // 获取站点名称（如果有）
    $feeds = jefrss_simple_get_feeds();
    $name = isset($feeds[$url]['name']) ? $feeds[$url]['name'] : '';
    
    // 使用统一函数获取图标URL
    return jefrss_get_site_icon_url($domain, $url, $name);
}

/**
 * 抓取 RSS 内容
 */
function jefrss_simple_fetch_feed($url) {
    try {
        if (!function_exists('fetch_feed')) {
            include_once(ABSPATH . WPINC . '/feed.php');
        }

        $feed = fetch_feed($url);
        if (is_wp_error($feed)) {
            throw new Exception($feed->get_error_message());
        }

        $feeds = jefrss_simple_get_feeds();
        if (!isset($feeds[$url])) {
            return false;
        }

        // 使用全局设置的抓取数量
        $fetch_count = get_option('jefrss_fetch_count', 3);
        
        // 添加调试日志
        jefrss_add_log('准备抓取: ' . $url . ' - 全局设置抓取篇数: ' . $fetch_count);
        
        // 设置 SimplePie 最大项目数
        $feed->set_item_limit($fetch_count * 2); // 设置更大的限制以确保可以获取足够的文章
        
        // 实际获取的文章数量
        $available_items = $feed->get_item_quantity();
        jefrss_add_log('源提供的文章数量: ' . $available_items);

        // 检查是否有新文章
        $old_items = isset($feeds[$url]['items']) ? $feeds[$url]['items'] : array();
        $old_links = array_column($old_items, 'link');
        
        $items = array();
        $new_count = 0;
        $latest_date = '';

        // 使用实际可用的文章数量，但不超过设置的数量
        $actual_fetch_count = min($available_items, $fetch_count);
        
        foreach ($feed->get_items(0, $actual_fetch_count) as $item) {
            // 检查是否是新文章
            if (!in_array($item->get_permalink(), $old_links)) {
                $new_count++;
            }
            
            // 获取文章日期并更新最新日期
            $item_date = $item->get_date();
            if ($item_date) {
                $gmt_date = get_gmt_from_date(date('Y-m-d H:i:s', strtotime($item_date)));
                if (empty($latest_date) || strtotime($gmt_date) > strtotime($latest_date)) {
                    $latest_date = $gmt_date;
                }
            }

            // 获取完整内容
            $content = $item->get_content();
            if (empty($content)) {
                $content = $item->get_description();
            }
            
            // 获取文章作者
            $author = $item->get_author();
            $author_name = '';
            if ($author) {
                $author_name = $author->get_name();
            }
            
            $items[] = array(
                'title' => $item->get_title(),
                'link' => $item->get_permalink(),
                'date' => $gmt_date,
                'author' => $author_name,
                'content' => $content,
                'description' => wp_trim_words($content, 55, '...')
            );
        }

        // 记录实际抓取的数量
        jefrss_add_log('实际抓取文章数: ' . count($items));
        
        // 更新订阅源数据
        $feeds[$url]['items'] = $items;
        $feeds[$url]['last_fetch'] = time();
        $feeds[$url]['last_update'] = $latest_date;  // 使用最新文章的日期作为站点最后更新时间
        $feeds[$url]['site_url'] = $feed->get_permalink();
        $feeds[$url]['description'] = $feed->get_description();
        
        // 保存到数据库
        update_option('jefrss_feeds', $feeds);

        return array(
            'success' => true,
            'new_count' => $new_count,
            'total_count' => count($items)
        );

    } catch (Exception $e) {
        return array(
            'success' => false,
            'error' => $e->getMessage()
        );
    }
}

/**
 * 获取日志记录
 * 
 * @param int $page 页码
 * @param int $per_page 每页显示数量
 * @return array 日志记录数组和分页信息
 */
function jefrss_get_logs($page = 1, $per_page = 20) {
    // 从数据库获取日志
    $logs = get_option('jefrss_logs', array());
    
    // 自动清理超过3天的日志
    $three_days_ago = time() - (3 * 24 * 60 * 60);
    $logs_count_before = count($logs);
    
    foreach ($logs as $key => $log) {
        // 确保时间戳转换正确
        $log_time = strtotime($log['time']);
        if ($log_time && $log_time < $three_days_ago) {
            unset($logs[$key]);
        }
    }
    
    // 如果有日志被清理，更新数据库
    if (count($logs) < $logs_count_before) {
        update_option('jefrss_logs', $logs);
    }
    
    // 按时间倒序排序（最新的在前）
    usort($logs, function($a, $b) {
        return strtotime($b['time']) - strtotime($a['time']);
    });
    
    // 计算分页信息
    $total_logs = count($logs);
    $total_pages = ceil($total_logs / $per_page);
    $page = max(1, min($page, $total_pages));
    $offset = ($page - 1) * $per_page;
    
    // 获取当前页的日志
    $current_logs = array_slice($logs, $offset, $per_page);
    
    return array(
        'logs' => $current_logs,
        'pagination' => array(
            'total' => $total_logs,
            'per_page' => $per_page,
            'current_page' => $page,
            'total_pages' => $total_pages
        )
    );
}

/**
 * 添加日志记录
 * 
 * @param string $message 日志消息
 * @return bool 成功返回true
 */
function jefrss_add_log($message) {
    // 获取现有日志
    $logs = get_option('jefrss_logs', array());
    
    // 添加新日志，使用 WordPress 本地时间
    $logs[] = array(
        'time' => current_time('mysql'),
        'message' => $message
    );
    
    // 只保留最近3天的日志
    $three_days_ago = strtotime('-3 days');
    $logs = array_filter($logs, function($log) use ($three_days_ago) {
        // 确保时间戳转换正确
        $log_time = strtotime($log['time']);
        return $log_time && $log_time > $three_days_ago;
    });
    
    // 限制日志数量
    if (count($logs) > 500) {
        $logs = array_slice($logs, -500);
    }
    
    // 保存日志
    update_option('jefrss_logs', array_values($logs));
}

/**
 * 删除订阅
 */
function jefrss_simple_delete_feed($url) {
    // 在任何输出之前启动输出缓冲
    if (!headers_sent()) {
        ob_start();
    }
    
    try {
        $feeds = jefrss_simple_get_feeds();
        
        if (!isset($feeds[$url])) {
            throw new Exception('订阅不存在');
        }
        
        // 删除图标文件
        $icon_file = JEFRSS_ICONS_DIR . md5(jefrss_simple_get_actual_domain($url)) . '.png';
        if (file_exists($icon_file)) {
            @unlink($icon_file);
        }
        
        // 删除订阅数据
        unset($feeds[$url]);
        
        // 保存到数据库
        if (update_option('jefrss_feeds', $feeds)) {
            // 清除并关闭输出缓冲
            if (ob_get_level()) {
                ob_end_clean();
            }
            
            // 设置成功消息
            add_settings_error(
                'jefrss_messages',
                'feed_deleted',
                '订阅已成功删除',
                'success'
            );
            
            // 重定向回列表页
            wp_redirect(admin_url('admin.php?page=jefrss-simple-sites&message=deleted'));
            exit;
        }
        
        throw new Exception('删除失败');
        
    } catch (Exception $e) {
        // 清除并关闭输出缓冲
        if (ob_get_level()) {
            ob_end_clean();
        }
        
        // 设置错误消息
        add_settings_error(
            'jefrss_messages',
            'feed_delete_error',
            $e->getMessage(),
            'error'
        );
        
        // 重定向回列表页并显示错误
        wp_redirect(admin_url('admin.php?page=jefrss-simple-sites&error=1'));
        exit;
    }
}

/**
 * 批量删除订阅源
 */
function jefrss_simple_batch_delete_feeds($feeds) {
    try {
        if (empty($feeds)) {
            throw new Exception('没有选择要删除的订阅源');
        }
        
        $all_feeds = jefrss_simple_get_feeds();
        $deleted_count = 0;
        
        foreach ($feeds as $url) {
            if (isset($all_feeds[$url])) {
                // 删除图标文件
                $icon_file = JEFRSS_ICONS_DIR . md5(jefrss_simple_get_actual_domain($url)) . '.png';
                if (file_exists($icon_file)) {
                    @unlink($icon_file);
                }
                
                // 从数组中删除该源
                unset($all_feeds[$url]);
                $deleted_count++;
            }
        }
        
        // 保存更新后的数据
        update_option('jefrss_feeds', $all_feeds);
        
        return array(
            'success' => true,
            'deleted_count' => $deleted_count,
            'message' => sprintf('成功删除 %d 个订阅源', $deleted_count)
        );
        
    } catch (Exception $e) {
        return array(
            'success' => false,
            'message' => $e->getMessage()
        );
    }
}

/**
 * 重命名订阅源
 */
function jefrss_simple_rename_feed($url, $new_name) {
    $feeds = jefrss_simple_get_feeds();
    
    if (!isset($feeds[$url])) {
        return array(
            'success' => false,
            'message' => '找不到指定的订阅源'
        );
    }
    
    // 更新名称
    $feeds[$url]['name'] = $new_name;
    
    // 保存到数据库
    if (update_option('jefrss_feeds', $feeds)) {
        return array(
            'success' => true,
            'message' => '订阅源名称已更新'
        );
    }
    
    return array(
        'success' => false,
        'message' => '更新失败'
    );
}

/**
 * 获取站点图标URL的统一函数
 * 
 * @param string $domain 站点域名
 * @param string $url 完整的站点URL
 * @param string $name 站点名称
 * @return string 图标URL
 */
function jefrss_get_site_icon_url($domain, $url = '', $name = '') {
    // 获取当前设置的图标来源
    $icon_source = get_option('jefrss_icon_source', 'local');
    
    // 如果URL为空但有域名，构建URL
    if (empty($url) && !empty($domain)) {
        $url = 'https://' . $domain;
    }
    
    // 如果域名为空但有URL，提取域名
    if (empty($domain) && !empty($url)) {
        $parsed_url = parse_url($url);
        $domain = isset($parsed_url['host']) ? $parsed_url['host'] : '';
    }
    
    // 如果域名仍然为空，返回默认图标
    if (empty($domain)) {
        return JEFRSS_PLUGIN_URL . '/icons/default.png';
    }
    
    // 检查是否使用本地图标
    if ($icon_source === 'local') {
        // 检查本地缓存
        $icon_path = JEFRSS_ICONS_DIR . sanitize_file_name($domain) . '.png';
        $icon_url = JEFRSS_PLUGIN_URL . '/icons/' . sanitize_file_name($domain) . '.png';
        
        // 如果本地有缓存，返回本地URL
        if (file_exists($icon_path)) {
            return $icon_url;
        }
        
        // 如果本地没有缓存，生成基于首字母的图标
        $firstChar = mb_substr(!empty($name) ? $name : $domain, 0, 1, 'UTF-8');
        return 'https://ui-avatars.com/api/?name=' . urlencode($firstChar) . '&background=random&size=64&bold=true';
    }
    
    // 使用外部服务商
    switch ($icon_source) {
        case 'favicon_h4ck':
            return 'https://favicon.h4ck.org.cn/api/redirect_favicon?url=' . urlencode($url);
            
        case 'favicon_im':
            return 'https://favicon.im/' . urlencode($domain);
            
        case 'cravatar':
            return 'https://cravatar.com/favicon/api/index.php?url=' . urlencode($domain);
            
        case 'unavatar':
            return 'https://unavatar.io/' . urlencode($domain);
            
        case 'afmax':
            return 'https://api.afmax.cn/so/ico/index.php?r=' . urlencode($url);
            
        default:
            // 默认使用UI Avatars生成基于首字母的图标
            $firstChar = mb_substr(!empty($name) ? $name : $domain, 0, 1, 'UTF-8');
            return 'https://ui-avatars.com/api/?name=' . urlencode($firstChar) . '&background=random&size=64&bold=true';
    }
}

/**
 * 定时任务处理
 */
function jefrss_simple_cron_exec() {
    $manager = Jefrss_Simple_Manager::get_instance();
    $feeds = $manager->get_feeds();
    
    foreach ($feeds as $url => $feed) {
        // 检查是否需要更新
        if (time() - $feed['last_fetch'] >= $feed['interval'] * 60) {
            $manager->fetch_feed($url);
        }
    }
}
add_action('jefrss_simple_cron_hook', 'jefrss_simple_cron_exec');

/**
 * AJAX 处理
 */
function jefrss_simple_detect_rss() {
    check_ajax_referer('jefrss_ajax_nonce', 'nonce');
    
    $url = isset($_POST['url']) ? esc_url_raw($_POST['url']) : '';
    if (empty($url)) {
        wp_send_json_error('URL 不能为空');
    }

    if (!function_exists('fetch_feed')) {
        include_once(ABSPATH . WPINC . '/feed.php');
    }

    $feed = fetch_feed($url);
    if (is_wp_error($feed)) {
        wp_send_json_error($feed->get_error_message());
    }

    wp_send_json_success();
}
add_action('wp_ajax_jefrss_detect_rss', 'jefrss_simple_detect_rss');

/**
 * 处理前端错误日志
 */
function jefrss_handle_error_log() {
    check_ajax_referer('jefrss_ajax_nonce', 'nonce');
    
    $level = isset($_POST['level']) ? sanitize_text_field($_POST['level']) : 'error';
    $message = isset($_POST['message']) ? sanitize_text_field($_POST['message']) : '';
    $data = isset($_POST['data']) ? sanitize_text_field($_POST['data']) : '';
    $url = isset($_POST['url']) ? esc_url_raw($_POST['url']) : '';
    $userAgent = isset($_POST['userAgent']) ? sanitize_text_field($_POST['userAgent']) : '';
    
    // 记录到日志文件
    $log_entry = sprintf(
        "[%s] [%s] %s\nURL: %s\nUser Agent: %s\nData: %s\n",
        current_time('mysql'),
        strtoupper($level),
        $message,
        $url,
        $userAgent,
        $data
    );
    
    $log_file = JEFRSS_LOGS_DIR . 'error.log';
    error_log($log_entry, 3, $log_file);
    
    wp_send_json_success();
}
add_action('wp_ajax_jefrss_log_error', 'jefrss_handle_error_log');

/**
 * 统一的错误处理函数
 */
function jefrss_handle_error($error, $context = '') {
    if (is_wp_error($error)) {
        $message = $error->get_error_message();
    } else {
        $message = (string)$error;
    }
    
    // 记录错误日志
    jefrss_add_log('错误 [' . $context . ']: ' . $message);
    
    // 如果是管理界面，显示错误消息
    if (is_admin()) {
        add_settings_error(
            'jefrss_messages',
            'jefrss_error',
            $message,
            'error'
        );
    }
    
    return false;
}

/**
 * 清理过期的抓取锁
 */
function jefrss_cleanup_fetch_lock() {
    $lock_key = 'jefrss_is_fetching';
    $lock_time = get_transient($lock_key);
    
    // 如果锁存在且已超过10分钟，强制清除
    if ($lock_time && (time() - $lock_time) > 600) {
        delete_transient($lock_key);
        jefrss_add_log('清理过期的抓取锁');
    }
}

// 每小时检查一次过期的锁
add_action('wp_scheduled_delete', 'jefrss_cleanup_fetch_lock');

/**
 * 获取定时任务状态
 * @return array 定时任务状态信息
 */
function jefrss_get_cron_status() {
    $lock_key = 'jefrss_is_fetching';
    $lock_time = get_transient($lock_key);
    $next_scheduled = wp_next_scheduled('jefrss_scheduled_fetch');
    $interval = get_option('jefrss_fetch_interval', 180);
    
    // 转换间隔显示
    $interval_text = '';
    switch ($interval) {
        case 60: $interval_text = '1小时'; break;
        case 120: $interval_text = '2小时'; break;
        case 180: $interval_text = '3小时'; break;
        case 360: $interval_text = '6小时'; break;
        case 720: $interval_text = '12小时'; break;
        case 1440: $interval_text = '24小时'; break;
        default: $interval_text = $interval . '分钟';
    }
    
    // 检查锁状态
    if ($lock_time) {
        if ((time() - $lock_time) > 600) {
            delete_transient($lock_key);
            $status = '空闲';
            $lock_time = null;
        } else {
            $status = '正在执行';
        }
    } else {
        $status = '空闲';
    }
    
    return array(
        'is_locked' => (bool)$lock_time,
        'lock_time' => $lock_time ? get_date_from_gmt(date('Y-m-d H:i:s', $lock_time), 'Y-m-d H:i:s') : null,
        'next_run' => $next_scheduled ? get_date_from_gmt(date('Y-m-d H:i:s', $next_scheduled), 'Y-m-d H:i:s') : null,
        'interval' => $interval_text,
        'status' => $status
    );
}

/**
 * 统一的锁定机制
 */
function jefrss_get_fetch_lock() {
    return get_transient('jefrss_is_fetching');
}

function jefrss_set_fetch_lock($timeout = 300) {
    return set_transient('jefrss_is_fetching', time(), $timeout);
}

function jefrss_release_fetch_lock() {
    return delete_transient('jefrss_is_fetching');
}

/**
 * 统一的抓取任务执行函数
 */
function jefrss_execute_fetch_task() {
    // 检查锁
    if (!jefrss_get_fetch_lock()) {
        jefrss_set_fetch_lock();
    }
    
    try {
        jefrss_add_log('=== 开始批量抓取 ===');
        
        $stats = array(
            'success' => 0,
            'failed' => 0,
            'new_articles' => 0,
            'failed_feeds' => array()
        );
        
        // 获取所有订阅源
        $feeds = jefrss_simple_get_feeds();
        
        foreach ($feeds as $url => $feed) {
            jefrss_add_log(sprintf('开始抓取: %s (%s)', $feed['name'], $url));
            
            $result = jefrss_simple_fetch_feed($url);
            
            if ($result['success']) {
                $stats['success']++;
                $stats['new_articles'] += $result['new_count'];
                jefrss_add_log(sprintf('抓取成功: %s，新增 %d 篇文章', $feed['name'], $result['new_count']));
            } else {
                $stats['failed']++;
                $stats['failed_feeds'][] = array(
                    'url' => $url,
                    'name' => $feed['name'],
                    'error' => isset($result['error']) ? $result['error'] : '未知错误'
                );
                jefrss_add_log(sprintf('抓取失败: %s - %s', $feed['name'], isset($result['error']) ? $result['error'] : '未知错误'));
            }
        }
        
        // 记录最终统计
        jefrss_add_log(sprintf(
            '批量抓取完成：成功 %d 个，失败 %d 个，新增文章 %d 篇',
            $stats['success'],
            $stats['failed'],
            $stats['new_articles']
        ));
        
        if (!empty($stats['failed_feeds'])) {
            jefrss_add_log('失败源详情：');
            foreach ($stats['failed_feeds'] as $failed) {
                jefrss_add_log(sprintf('- %s (%s): %s', $failed['name'], $failed['url'], $failed['error']));
            }
        }
        
        jefrss_add_log('=== 批量抓取结束 ===');
        
        // 抓取完成后添加成功通知
        add_settings_error(
            'jefrss_messages',
            'jefrss_fetch_success',
            sprintf(
                '抓取完成：成功 %d 个，失败 %d 个，新增文章 %d 篇',
                $stats['success'],
                $stats['failed'],
                $stats['new_articles']
            ),
            'success'
        );
        
        return array('success' => true, 'stats' => $stats);
        
    } catch (Exception $e) {
        jefrss_add_log('抓取任务执行出错：' . $e->getMessage());
        return array('success' => false, 'message' => $e->getMessage());
    } finally {
        jefrss_release_fetch_lock();
    }
}

/**
 * 单个源的抓取入口
 */
function jefrss_execute_single_feed_task($url) {
    $lock_key = 'jefrss_is_fetching';
    
    // 检查是否已经在抓取
    if (get_transient($lock_key)) {
        return array(
            'success' => false,
            'message' => '已有抓取任务正在进行中'
        );
    }
    
    // 设置锁定
    set_transient($lock_key, time(), 10 * MINUTE_IN_SECONDS);
    
    try {
        $feeds = jefrss_simple_get_feeds();
        if (!isset($feeds[$url])) {
            throw new Exception('找不到指定的订阅源');
        }
        
        $feed = $feeds[$url];
        $result = jefrss_simple_fetch_feed($url);
        
        if ($result['success']) {
            jefrss_add_log(sprintf(
                '单源抓取成功：%s，新增文章 %d 篇',
                $feed['name'],
                $result['new_count']
            ));
        } else {
            jefrss_add_log(sprintf(
                '单源抓取失败：%s (%s) - %s',
                $feed['name'],
                $url,
                $result['error']
            ));
        }
        
        return $result;
        
    } catch (Exception $e) {
        jefrss_add_log('抓取任务执行出错：' . $e->getMessage());
        return array(
            'success' => false,
            'message' => $e->getMessage()
        );
    } finally {
        // 确保释放锁定
        delete_transient($lock_key);
    }
}

function jefrss_format_date($date_string) {
    // 将GMT时间转换为本地时间
    $local_date = get_date_from_gmt($date_string);
    
    // 获取 WordPress 设置的时区
    $wp_timezone = wp_timezone();
    
    // 创建 DateTime 对象，使用本地时间
    $date = new DateTime($local_date);
    
    // 设置为 WordPress 的时区
    $date->setTimezone($wp_timezone);
    
    // 获取当前时间（使用相同时区）
    $now = new DateTime('now', $wp_timezone);
    
    // 计算时间差（确保是正数）
    $diff = $now->getTimestamp() - $date->getTimestamp();
    $diff = abs($diff);
    
    // 格式化相对时间
    if ($diff < 3600) { // 1小时内
        $mins = floor($diff / 60);
        return $mins . ' 分钟前';
    } elseif ($diff < 86400) { // 24小时内
        $hours = floor($diff / 3600);
        return $hours . ' 小时前';
    } elseif ($diff < 604800) { // 7天内
        $days = floor($diff / 86400);
        return $days . ' 天前';
    } elseif ($diff < 2592000) { // 30天内
        $weeks = floor($diff / 604800);
        return $weeks . ' 周前';
    } elseif ($diff < 31536000) { // 365天内
        $months = floor($diff / 2592000);
        return $months . ' 个月前';
    } else {
        $years = floor($diff / 31536000);
        return $years . ' 年前';
    }
} 