<?php
// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

/**
 * OPML 处理类
 */
class Jefrss_Simple_OPML {
    private static $instance = null;
    
    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    /**
     * 导出 OPML
     */
    public function export() {
        // 检查权限
        if (!current_user_can('manage_options')) {
            wp_die('权限不足');
        }

        // 验证nonce
        check_admin_referer('export_opml');

        $manager = Jefrss_Simple_Manager::get_instance();
        $feeds = $manager->get_feeds();
        
        header('Content-Type: application/xml; charset=utf-8');
        header('Content-Disposition: attachment; filename="feeds_' . date('Y-m-d') . '.opml"');
        
        echo '<?xml version="1.0" encoding="UTF-8"?>' . "\n";
        echo '<opml xmlns:frss="https://freshrss.org/opml" version="2.0">' . "\n";
        echo '<head>' . "\n";
        echo '<title>Jefrss Simple Export</title>' . "\n";
        echo '<dateCreated>' . date(DATE_RSS) . '</dateCreated>' . "\n";
        echo '</head>' . "\n";
        echo '<body>' . "\n";
        echo '<outline text="订阅源">' . "\n";
        
        foreach ($feeds as $url => $feed) {
            echo sprintf(
                '  <outline text="%s" type="rss" xmlUrl="%s" htmlUrl="%s" description="%s"/>' . "\n",
                esc_attr($feed['name']),
                esc_attr($url),
                esc_attr(isset($feed['site_url']) ? $feed['site_url'] : $url),
                esc_attr(isset($feed['description']) ? $feed['description'] : $feed['name'])
            );
        }
        
        echo '</outline>' . "\n";
        echo '</body>' . "\n";
        echo '</opml>';
        exit;
    }

    /**
     * 导入 OPML
     */
    public function import($file, $log_file = null) {
        if ($log_file) {
            $this->log_message('开始解析OPML文件: ' . $file, $log_file);
        }
        
        if (!file_exists($file)) {
            if ($log_file) {
                $this->log_message('文件不存在: ' . $file, $log_file);
            }
            return array(
                'success' => false,
                'message' => '文件不存在: ' . $file
            );
        }

        // 读取文件内容
        $content = file_get_contents($file);
        if ($content === false) {
            if ($log_file) {
                $this->log_message('无法读取文件内容', $log_file);
            }
            return array(
                'success' => false,
                'message' => '无法读取文件内容'
            );
        }
        
        if ($log_file) {
            $this->log_message('文件内容: ' . substr($content, 0, 500) . '...', $log_file);
        }

        // 尝试加载 XML
        libxml_use_internal_errors(true);
        $xml = simplexml_load_string($content);
        $errors = libxml_get_errors();
        libxml_clear_errors();

        if (!$xml) {
            $error_msg = '无效的 OPML 文件';
            if (!empty($errors)) {
                $error_details = array();
                foreach ($errors as $error) {
                    $error_details[] = sprintf(
                        "行 %d, 列 %d: %s",
                        $error->line,
                        $error->column,
                        $error->message
                    );
                }
                $error_msg .= ': ' . implode('; ', $error_details);
                if ($log_file) {
                    $this->log_message('XML解析错误: ' . $error_msg, $log_file);
                }
            }
            return array(
                'success' => false,
                'message' => $error_msg,
                'errors' => $errors
            );
        }

        // 检查是否有 body 和 outline 元素
        if (!isset($xml->body)) {
            if ($log_file) {
                $this->log_message('OPML缺少body元素', $log_file);
            }
            return array(
                'success' => false,
                'message' => 'OPML 文件缺少必要的元素 (body)'
            );
        }
        
        if (!isset($xml->body->outline)) {
            if ($log_file) {
                $this->log_message('OPML缺少outline元素', $log_file);
            }
            return array(
                'success' => false,
                'message' => 'OPML 文件缺少必要的元素 (outline)'
            );
        }

        // 提取所有订阅源
        $feeds_data = array();
        $this->extract_feeds($xml->body->outline, $feeds_data, $log_file);
        
        if (empty($feeds_data)) {
            if ($log_file) {
                $this->log_message('未找到有效的订阅源', $log_file);
            }
            return array(
                'success' => false,
                'message' => '未找到有效的订阅源'
            );
        }
        
        if ($log_file) {
            $this->log_message('找到 ' . count($feeds_data) . ' 个订阅源', $log_file);
        }

        // 批量保存订阅源
        $manager = Jefrss_Simple_Manager::get_instance();
        $results = $this->batch_save_feeds($feeds_data, $manager);
        
        if ($log_file) {
            $this->log_message('导入结果: ' . print_r($results, true), $log_file);
        }

        return array(
            'success' => true,
            'imported' => count($results['success']),
            'failed' => count($results['failed']),
            'details' => $results
        );
    }

    /**
     * 递归提取订阅源
     */
    private function extract_feeds($outline, &$feeds, $log_file = null) {
        foreach ($outline as $item) {
            $attributes = $item->attributes();
            
            // 如果有子元素，递归处理
            if (isset($item->outline)) {
                $this->extract_feeds($item->outline, $feeds, $log_file);
                continue;
            }
            
            // 检查是否是RSS订阅源
            if (isset($attributes['xmlUrl'])) {
                $url = (string)$attributes['xmlUrl'];
                
                if (empty($url)) {
                    continue;
                }
                
                $feed = array(
                    'url' => $url,
                    'name' => isset($attributes['text']) ? (string)$attributes['text'] : '',
                    'site_url' => isset($attributes['htmlUrl']) ? (string)$attributes['htmlUrl'] : '',
                    'description' => isset($attributes['description']) ? (string)$attributes['description'] : ''
                );
                
                // 如果没有名称，使用URL
                if (empty($feed['name'])) {
                    $feed['name'] = $url;
                }
                
                $feeds[] = $feed;
                
                if ($log_file) {
                    $this->log_message('找到订阅源: ' . $url, $log_file);
                }
            }
        }
    }

    /**
     * 批量保存订阅源
     */
    private function batch_save_feeds($feeds_data, $manager) {
        $results = array(
            'success' => array(),
            'failed' => array()
        );
        
        // 获取当前所有订阅源
        $current_feeds = $manager->get_feeds();
        
        foreach ($feeds_data as $feed) {
            if (empty($feed['url'])) {
                continue;
            }
            
            $url = $feed['url'];
            $name = isset($feed['name']) ? $feed['name'] : '';
            $site_url = isset($feed['site_url']) ? $feed['site_url'] : '';
            $description = isset($feed['description']) ? $feed['description'] : '';
            
            // 检查是否已存在
            if (isset($current_feeds[$url])) {
                $results['failed'][] = array(
                    'url' => $url,
                    'message' => '该订阅地址已存在'
                );
                continue;
            }
            
            // 获取域名
            $domain = parse_url($url, PHP_URL_HOST);
            if (empty($domain)) {
                $domain = 'unknown';
            }
            
            // 如果未提供站点名称,使用URL的主机名作为默认名称
            if (empty($name)) {
                $name = $domain;
            }
            
            // 添加新订阅源
            $current_feeds[$url] = array(
                'name' => $name,
                'url' => $url,
                'site_url' => $site_url,
                'description' => $description,
                'interval' => 60, // 默认1小时
                'fetch_count' => 3, // 默认获取3篇
                'last_fetch' => 0,
                'icon' => '',
                'icon_status' => 'pending',
                'items' => array()
            );
            
            $results['success'][] = $url;
        }
        
        // 批量保存所有新添加的订阅源
        update_option('jefrss_feeds', $current_feeds);
        
        return $results;
    }

    /**
     * AJAX处理导入请求
     */
    public function handle_import_ajax() {
        // 检查权限
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => '权限不足'));
            return;
        }

        // 验证nonce
        check_ajax_referer('import_opml', 'nonce');
        
        // 设置日志文件
        $log_dir = JEFRSS_PLUGIN_DIR . 'logs';
        if (!file_exists($log_dir)) {
            wp_mkdir_p($log_dir);
        }
        $log_file = $log_dir . '/import_' . date('Y-m-d_H-i-s') . '.log';
        
        $this->log_message('开始处理AJAX导入请求', $log_file);
        $this->log_message('$_POST: ' . print_r($_POST, true), $log_file);
        $this->log_message('$_FILES: ' . print_r($_FILES, true), $log_file);

        // 检查文件上传
        if (!isset($_FILES['opml_file'])) {
            $this->log_message('未上传文件: $_FILES[opml_file]不存在', $log_file);
            $this->log_message('$_FILES内容: ' . print_r($_FILES, true), $log_file);
            $this->log_message('$_POST内容: ' . print_r($_POST, true), $log_file);
            wp_send_json_error(array('message' => '未上传文件'));
            return;
        }

        $file = $_FILES['opml_file'];
        $this->log_message('文件信息: ' . print_r($file, true), $log_file);
        
        // 检查上传错误
        if ($file['error'] !== UPLOAD_ERR_OK) {
            $error_message = $this->get_upload_error_message($file['error']);
            $this->log_message('文件上传错误: ' . $error_message . ' (代码: ' . $file['error'] . ')', $log_file);
            wp_send_json_error(array('message' => '文件上传错误: ' . $error_message));
            return;
        }
        
        // 验证文件类型
        $this->log_message('文件类型: ' . $file['type'], $log_file);
        
        // 放宽文件类型限制，只检查扩展名
        $file_extension = pathinfo($file['name'], PATHINFO_EXTENSION);
        if (!in_array(strtolower($file_extension), array('opml', 'xml'))) {
            $this->log_message('不支持的文件扩展名: ' . $file_extension, $log_file);
            wp_send_json_error(array(
                'message' => '不支持的文件类型，请使用.opml或.xml文件',
                'extension' => $file_extension
            ));
            return;
        }

        // 检查文件是否存在
        if (!file_exists($file['tmp_name'])) {
            $this->log_message('临时文件不存在: ' . $file['tmp_name'], $log_file);
            wp_send_json_error(array('message' => '上传的文件无法访问'));
            return;
        }
        
        // 检查文件大小
        if ($file['size'] == 0) {
            $this->log_message('文件大小为0', $log_file);
            wp_send_json_error(array('message' => '上传的文件为空'));
            return;
        }
        
        // 读取文件内容进行调试
        $file_content = file_get_contents($file['tmp_name']);
        if ($file_content === false) {
            $this->log_message('无法读取文件内容', $log_file);
            wp_send_json_error(array('message' => '无法读取文件内容'));
            return;
        }
        
        $this->log_message('文件内容前100字符: ' . substr($file_content, 0, 100), $log_file);
        
        try {
            // 导入处理
            $this->log_message('开始导入OPML', $log_file);
            $result = $this->import($file['tmp_name'], $log_file);
            $this->log_message('导入结果: ' . print_r($result, true), $log_file);
            
            if (isset($result['success']) && $result['success'] || 
                (isset($result['imported']) && $result['imported'] > 0)) {
                wp_send_json_success($result);
            } else {
                wp_send_json_error($result);
            }
        } catch (Exception $e) {
            $this->log_message('导入过程中发生异常: ' . $e->getMessage(), $log_file);
            $this->log_message('异常堆栈: ' . $e->getTraceAsString(), $log_file);
            wp_send_json_error(array(
                'message' => '导入过程中发生错误: ' . $e->getMessage(),
                'trace' => $e->getTraceAsString()
            ));
        }
    }

    /**
     * 获取上传错误消息
     */
    private function get_upload_error_message($error_code) {
        switch ($error_code) {
            case UPLOAD_ERR_INI_SIZE:
                return '上传的文件超过了 php.ini 中 upload_max_filesize 指令的限制';
            case UPLOAD_ERR_FORM_SIZE:
                return '上传的文件超过了 HTML 表单中 MAX_FILE_SIZE 指令的限制';
            case UPLOAD_ERR_PARTIAL:
                return '文件只有部分被上传';
            case UPLOAD_ERR_NO_FILE:
                return '没有文件被上传';
            case UPLOAD_ERR_NO_TMP_DIR:
                return '找不到临时文件夹';
            case UPLOAD_ERR_CANT_WRITE:
                return '文件写入失败';
            case UPLOAD_ERR_EXTENSION:
                return '文件上传因扩展程序而停止';
            default:
                return '未知上传错误';
        }
    }

    /**
     * 记录日志消息
     */
    private function log_message($message, $log_file = null) {
        if (empty($log_file)) {
            return;
        }
        
        $timestamp = date('[Y-m-d H:i:s]');
        $log_entry = $timestamp . ' ' . $message . PHP_EOL;
        
        // 确保日志目录存在
        $log_dir = dirname($log_file);
        if (!file_exists($log_dir)) {
            wp_mkdir_p($log_dir);
            @chmod($log_dir, 0755);
        }
        
        // 确保日志文件存在
        if (!file_exists($log_file)) {
            @touch($log_file);
            @chmod($log_file, 0644);
        }
        
        // 写入日志
        @file_put_contents($log_file, $log_entry, FILE_APPEND);
    }
}

// 保留导出功能
add_action('admin_init', function() {
    if (isset($_GET['page']) && $_GET['page'] === 'jefrss-simple' 
        && isset($_GET['action']) && $_GET['action'] === 'export') {
        Jefrss_Simple_OPML::get_instance()->export();
    }
});
