<?php
// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

/**
 * RSS Feed 短代码
 * 用法: [rss_feed display_length="200" article_count="10"]
 */
function jefrss_simple_render_feeds($atts = array()) {
    // 获取设置
    $atts = shortcode_atts(array(
        'display_length' => 200,  // 摘要长度
        'article_count' => 10     // 显示文章数量
    ), $atts);
    
    // 从选项中获取当前主题
    $current_theme = get_option('jefrss_selected_theme', 'default');
    
    $manager = Jefrss_Simple_Manager::get_instance();
    $feeds = $manager->get_feeds();
    
    if (empty($feeds)) {
        return '<p>暂无订阅内容</p>';
    }
    
    // 统一处理数据结构
    $processed_feeds = array();
    foreach ($feeds as $url => $data) {
        if (isset($data['items']) && !empty($data['items'])) {
            // 确保站点内文章按时间排序
            usort($data['items'], function($a, $b) {
                return strtotime($b['date']) - strtotime($a['date']);
            });
            
            $processed_feeds[$url] = array(
                'feed' => array(
                    'name' => $data['name'],
                    'items' => $data['items']
                )
            );
        }
    }
    
    // 根据当前主题选择渲染方法
    switch ($current_theme) {
        case 'card':
            return render_card_theme($processed_feeds, $atts);
        case 'timeline':
            return render_timeline_theme($processed_feeds, $atts);
        case 'grid':
            return render_grid_theme($processed_feeds, $atts);
        case 'magazine':
            return render_magazine_theme($processed_feeds, $atts);
        case 'minimal':
            return render_minimal_theme($processed_feeds, $atts);
        default:
            return render_default_theme($processed_feeds, $atts);
    }
}
add_shortcode('rss_feed', 'jefrss_simple_render_feeds');

/**
 * 默认主题渲染 - 参考 https://www.jeffer.xyz/jefrssfriends
 * 单列布局，每个文章项包含：站点图标、站点名称、文章标题、发布时间
 */
function render_default_theme($feeds, $atts) {
    $output = '<div class="jefrss-theme jefrss-theme-default">';
    
    // 合并所有文章并按时间排序
    $all_articles = array();
    foreach ($feeds as $url => $data) {
        $feed = $data['feed'];
        foreach ($feed['items'] as $item) {
            $all_articles[] = array(
                'item' => $item,
                'site_name' => $feed['name'],
                'site_icon' => jefrss_get_site_icon_url(parse_url($url, PHP_URL_HOST)),
                'site_url' => $url
            );
        }
    }
    
    // 按时间排序
    usort($all_articles, function($a, $b) {
        return strtotime($b['item']['date']) - strtotime($a['item']['date']);
    });
    
    // 限制文章数量
    $all_articles = array_slice($all_articles, 0, intval($atts['article_count']));
    
    foreach ($all_articles as $article) {
        $title = mb_strimwidth($article['item']['title'], 0, 60, '...', 'UTF-8');
        $output .= sprintf(
            '<article class="jefrss-article">
                <div class="jefrss-article-header">
                    <div class="jefrss-site-info">
                        <img src="%s" alt="%s" class="jefrss-site-icon" />
                        <span class="jefrss-site-name">%s</span>
                    </div>
                    <time class="jefrss-article-date">%s</time>
                </div>
                <h2 class="jefrss-article-title">
                    <a href="%s" target="_blank" title="%s">%s</a>
                </h2>
                <div class="jefrss-article-excerpt">%s</div>
            </article>',
            esc_url($article['site_icon']),
            esc_attr($article['site_name']),
            esc_html($article['site_name']),
            esc_html(jefrss_format_date($article['item']['date'])),
            esc_url($article['item']['link']),
            esc_attr($article['item']['title']),
            esc_html($title),
            esc_html(wp_trim_words($article['item']['description'], $atts['display_length']))
        );
    }
    
    $output .= '</div>';
    return $output;
}

/**
 * 现代主题渲染 - 参考 https://h4ck.org.cn/besties
 */
function render_card_theme($feeds, $atts) {
    $output = '<div class="jefrss-theme-card-wrapper">';
    $output .= '<div class="jefrss-theme jefrss-theme-card" style="display:grid;gap:24px;">';
    
    // 合并所有文章并按时间排序
    $all_articles = array();
    
    foreach ($feeds as $url => $data) {
        $feed = $data['feed'];
        foreach ($feed['items'] as $item) {
            $all_articles[] = array(
                'item' => $item,
                'site_name' => $feed['name'],
                'site_icon' => jefrss_get_site_icon_url(parse_url($url, PHP_URL_HOST)),
                'site_url' => $url
            );
        }
    }
    
    // 按时间排序
    usort($all_articles, function($a, $b) {
        return strtotime($b['item']['date']) - strtotime($a['item']['date']);
    });
    
    // 限制文章数量
    $all_articles = array_slice($all_articles, 0, intval($atts['article_count']));
    
    // 渲染文章列表
    foreach ($all_articles as $article) {
        $full_title = esc_html($article['item']['title']);
        $short_title = mb_strimwidth($article['item']['title'], 0, 45, '...', 'UTF-8');
        
        $output .= sprintf(
            '<article class="jefrss-card" style="margin-bottom:24px;">  <!-- 添加内联样式 -->
                <div class="jefrss-site-info">
                    <div class="jefrss-site-icon-wrapper">
                        <img src="%s" alt="%s" class="jefrss-site-icon">
                    </div>
                    <div class="jefrss-site-content">
                        <div class="jefrss-site-header">
                            <span class="jefrss-site-name">%s</span>
                            <span class="jefrss-published">发布了：</span>
                            <a href="%s" target="_blank"class="jefrss-article-title" title="%s">%s</a>
                        </div>
                        <time class="jefrss-article-date">%s</time>
                        <div class="jefrss-article-excerpt">%s</div>
                    </div>
                </div>
            </article>',
            esc_url($article['site_icon']),
            esc_attr($article['site_name']),
            esc_html($article['site_name']),
            esc_url($article['item']['link']),
            $full_title,
            esc_html($short_title),
            esc_html(jefrss_format_date($article['item']['date'])),
            esc_html(wp_trim_words($article['item']['description'], $atts['display_length']))
        );
    }
    
    $output .= '</div></div>';
    return $output;
}

/**
 * 时间线主题渲染 - 参考 https://my1981.cn/friends.html
 */
function render_timeline_theme($feeds, $atts) {
    $output = '<div class="jefrss-theme jefrss-theme-timeline">';
    
    // 合并所有文章并按时间排序
    $all_articles = array();
    foreach ($feeds as $url => $data) {
        $feed = $data['feed'];
        foreach ($feed['items'] as $item) {
            $all_articles[] = array(
                'item' => $item,
                'site_name' => $feed['name'],
                'site_icon' => jefrss_get_site_icon_url(parse_url($url, PHP_URL_HOST)),
                'site_url' => $url
            );
        }
    }
    
    // 按时间排序
    usort($all_articles, function($a, $b) {
        return strtotime($b['item']['date']) - strtotime($a['item']['date']);
    });
    
    // 限制文章数量
    $all_articles = array_slice($all_articles, 0, intval($atts['article_count']));
    
    foreach ($all_articles as $article) {
        $full_title = esc_html($article['item']['title']);
        $short_title = mb_strimwidth($article['item']['title'], 0, 45, '...', 'UTF-8');
        
        $output .= sprintf(
            '<article class="jefrss-timeline-item">
                <div class="jefrss-timeline-meta">
                    <time class="jefrss-timeline-date">%s</time>
                    <div class="jefrss-timeline-dot"></div>
                </div>
                <div class="jefrss-timeline-content">
                    <div class="jefrss-site-info">
                        <img src="%s" alt="%s" class="jefrss-site-icon" />
                        <span class="jefrss-site-name">%s</span>
                    </div>
                    <h3 class="jefrss-article-title">
                        <a href="%s" target="_blank" title="%s">%s</a>
                    </h3>
                    <div class="jefrss-article-excerpt">%s</div>
                </div>
            </article>',
            esc_html(date('Y-m-d', strtotime($article['item']['date']))),
            esc_url($article['site_icon']),
            esc_attr($article['site_name']),
            esc_html($article['site_name']),
            esc_url($article['item']['link']),
            $full_title,
            esc_html($short_title),
            esc_html(jefrss_format_date($article['item']['date'])),
            esc_html(wp_trim_words($article['item']['description'], $atts['display_length']))
        );
    }
    
    $output .= '</div>';
    return $output;
}

/**
 * 杂志主题渲染 - 参考 https://www.evan.xin/you/
 */
function render_grid_theme($feeds, $atts) {
    $output = '<div class="jefrss-theme jefrss-theme-grid">';
    
    // 先按站点最新文章时间排序
    $sorted_sites = array();
    foreach ($feeds as $url => $data) {
        $feed = $data['feed'];
        if (!empty($feed['items'])) {
            // 确保站点内的文章按时间排序
            usort($feed['items'], function($a, $b) {
                return strtotime($b['date']) - strtotime($a['date']);
            });
            
            // 获取站点最新文章的时间
            $latest_date = strtotime($feed['items'][0]['date']);
            $sorted_sites[$url] = array(
                'feed' => $feed,
                'latest_date' => $latest_date
            );
        }
    }
    
    // 按站点最新文章时间排序
    uasort($sorted_sites, function($a, $b) {
        return $b['latest_date'] - $a['latest_date'];
    });
    
    foreach ($sorted_sites as $url => $data) {
        $feed = $data['feed'];
        // 每个站点都是一个独立的块
        $output .= '<div class="jefrss-site-block">';
        $site_icon = jefrss_get_site_icon_url(parse_url($url, PHP_URL_HOST));
        
        // 左侧站点图标
        $output .= sprintf(
            '<div class="jefrss-site-icon-wrapper">
                <img src="%s" alt="%s" class="jefrss-site-icon" />
            </div>',
            esc_url($site_icon),
            esc_attr($feed['name'])
        );
        
        // 右侧文章内容
        $output .= '<div class="jefrss-site-articles">';
        // 只显示最新的2-3篇文章
        $articles = array_slice($feed['items'], 0, 3);
        foreach ($articles as $item) {
            $output .= sprintf(
                '<div class="jefrss-article-item">
                    <h3 class="jefrss-article-title">
                        <a href="%s" target="_blank">%s</a>
                    </h3>
                    <time class="jefrss-article-date">%s</time>
                </div>',
                esc_url($item['link']),
                esc_html($item['title']),
                esc_html(jefrss_format_date($item['date']))
            );
        }
        $output .= '</div></div>';
    }
    
    $output .= '</div>';
    return $output;
}

/**
 * 网格主题渲染 - 参考 https://blog.liushen.fun/fcircle/
 */
function render_magazine_theme($feeds, $atts) {
    $output = '<div class="jefrss-theme-wrapper">';
    $output .= '<div class="jefrss-theme jefrss-theme-magazine">';
    
    // 合并所有文章并按时间排序
    $all_articles = array();
    foreach ($feeds as $url => $data) {
        $feed = $data['feed'];
        foreach ($feed['items'] as $item) {
            $all_articles[] = array(
                'item' => $item,
                'site_name' => $feed['name'],
                'site_icon' => jefrss_get_site_icon_url(parse_url($url, PHP_URL_HOST)),
                'site_url' => $url
            );
        }
    }
    
    // 按时间排序
    usort($all_articles, function($a, $b) {
        return strtotime($b['item']['date']) - strtotime($a['item']['date']);
    });
    
    // 限制文章数量
    $all_articles = array_slice($all_articles, 0, intval($atts['article_count']));
    
    // 渲染文章列表
    foreach ($all_articles as $article) {
        $output .= sprintf(
            '<article class="jefrss-magazine-item">
                <div class="jefrss-magazine-content">
                    <h3 class="jefrss-article-title">
                        <a href="%s" target="_blank">%s</a>
                    </h3>
                    <div class="jefrss-magazine-footer">
                        <div class="jefrss-site-info">
                            <img src="%s" alt="%s" class="jefrss-site-icon" />
                            <span class="jefrss-site-name">%s</span>
                        </div>
                        <time class="jefrss-article-date">%s</time>
                    </div>
                </div>
                <div class="jefrss-magazine-bg" style="background-image: url(%s)"></div>
            </article>',
            esc_url($article['item']['link']),
            esc_html($article['item']['title']),
            esc_url($article['site_icon']),
            esc_attr($article['site_name']),
            esc_html($article['site_name']),
            esc_html(jefrss_format_date($article['item']['date'])),
            esc_url($article['site_icon'])
        );
    }
    
    $output .= '</div>';
    $output .= '</div>';
    return $output;
}

function render_minimal_theme($feeds, $atts) {
    $count = 0;
    $output = '<div class="jefrss-feed-container jefrss-theme-minimal">';
    
    // 合并所有文章并按时间排序
    $all_articles = array();
    foreach ($feeds as $url => $data) {
        $feed = $data['feed'];
        foreach ($feed['items'] as $item) {
            if ($count >= intval($atts['article_count'])) break;
            $all_articles[] = array(
                'item' => $item,
                'site_name' => $feed['name'],
                'site_icon' => jefrss_get_site_icon_url(parse_url($url, PHP_URL_HOST)),
                'site_url' => $url
            );
            $count++;
        }
    }
    
    // 按时间排序
    usort($all_articles, function($a, $b) {
        return strtotime($b['item']['date']) - strtotime($a['item']['date']);
    });
    
    foreach ($all_articles as $article) {
        $output .= sprintf(
            '<article class="jefrss-minimal-item">
                <div class="jefrss-minimal-header">
                    <h3 class="jefrss-article-title">
                        <a href="%s" target="_blank">%s</a>
                    </h3>
                    <div class="jefrss-article-meta">
                        <time class="jefrss-article-date">%s</time>
                        <span class="jefrss-site-name">%s</span>
                    </div>
                </div>
                <div class="jefrss-article-excerpt">%s</div>
            </article>',
            esc_url($article['item']['link']),
            esc_html($article['item']['title']),
            esc_html(jefrss_format_date($article['item']['date'])),
            esc_html($article['site_name']),
            esc_html(wp_trim_words($article['item']['description'], 100))
        );
    }
    
    $output .= '</div>';
    return $output;
}

/**
 * RSS订阅短代码处理函数
 */
function jefrss_shortcode($atts) {
    // 尝试从缓存获取
    $cache_key = 'jefrss_rendered_feeds_' . md5(serialize($atts));
    $output = get_transient($cache_key);
    
    if (false === $output) {
        // 缓存未命中，重新生成
        $feeds = get_option('jefrss_feeds', array());
        if (empty($feeds)) {
            return '<p>暂无订阅内容</p>';
        }

        $atts = shortcode_atts(array(
            'display_length' => get_option('jefrss_display_length', 150),
            'article_count' => get_option('jefrss_article_count', 10),
            'theme' => get_option('jefrss_selected_theme', 'default')
        ), $atts);

        // 使用主题管理器渲染内容
        $theme_manager = Jefrss_Theme_Manager::get_instance();
        $output = $theme_manager->render_theme($atts['theme'], $feeds, array(
            'display_length' => intval($atts['display_length']),
            'article_count' => intval($atts['article_count'])
        ));
        
        // 缓存渲染结果，设置15分钟过期
        set_transient($cache_key, $output, 15 * MINUTE_IN_SECONDS);
    }
    
    return $output;
} 