<?php
// 防止直接访问
if (!defined('ABSPATH')) {
    exit;
}

/**
 * 主题样式管理类
 */
class Jefrss_Theme_Manager {
    private static $instance = null;
    
    // 主题配置
    private $themes = array(
        'default' => array(
            'name' => '默认主题',
            'reference' => 'jeffer.xyz',
            'description' => '简洁的列表布局，带站点图标和时间线',
            'dark_mode' => true
        ),
        'card' => array(
            'name' => '现代主题',
            'reference' => 'h4ck.org.cn',
            'description' => '现代布局大方美观，带悬停效果',
            'dark_mode' => true
        ),
        'timeline' => array(
            'name' => '时间线主题',
            'reference' => 'my1981.cn',
            'description' => '垂直时间线布局',
            'dark_mode' => true
        ),
        'grid' => array(
            'name' => '杂志主题',
            'reference' => 'evan.xin',
            'description' => '类似博客的布局',
            'dark_mode' => true
        ),
        'magazine' => array(
            'name' => '网格主题',
            'reference' => 'liushen.fun',
            'description' => '紧凑的网格布局',
            'dark_mode' => true
        ),
        'minimal' => array(
            'name' => '极简主题',
            'reference' => 'feng.pub',
            'description' => '单列极简布局',
            'dark_mode' => true
        )
    );
    
    // 获取实例
    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    /**
     * 获取所有可用主题
     */
    public function get_available_themes() {
        return $this->themes;
    }

    /**
     * 渲染指定主题的内容
     */
    public function render_theme($theme_id, $feeds, $atts) {
        $method = 'render_' . $theme_id . '_theme';
        if (method_exists($this, $method)) {
            return $this->$method($feeds, $atts);
        }
        return $this->render_default_theme($feeds, $atts);
    }

    /**
     * 获取当前主题的样式
     */
    public function get_theme_styles() {
        // 从选项中获取当前主题
        $theme = get_option('jefrss_selected_theme', 'default');
        $method = 'get_' . $theme . '_theme_styles';
        
        if (method_exists($this, $method)) {
            return $this->$method();
        }
        
        return $this->get_default_theme_styles();
    }

    /**
     * 获取基础样式 - 所有主题共用
     */
    private function get_base_styles() {
        $css = '
        /* 基础变量 - 明亮模式 */
        .jefrss-theme {
            --theme-primary: #2271b1;
            --theme-text:rgba(51, 51, 51, 0.79);
           
            --theme-meta: #666666;
            --theme-light: #999999;
            --theme-border: #eaeaea;
            --theme-card-bg: #ffffff;
            --theme-hover-bg: #f8f9fa;
        }

        /* 暗色模式样式 */
        @media (prefers-color-scheme: dark) {
            .jefrss-theme {
                --theme-primary: #72aee6;
                --theme-text: #ffffff;
                --theme-bg:rgba(29, 35, 39, 0);
                --theme-meta:rgb(116, 115, 115);
                --theme-light: #888888;
                --theme-border: #404c56;
              
                --theme-hover-bg:rgba(45, 55, 72, 0);
            }
        }';

        return $css;
    }

    /**
     * 注入主题样式
     */
    public function inject_theme_styles() {
        if (!is_admin()) {
            $styles = $this->get_base_styles() . $this->get_theme_styles();
            
            echo '<style type="text/css" id="jefrss-theme-styles" data-version="' . JEFRSS_VERSION . '">' 
                 . $this->minify_css($styles) . '</style>';
        }
    }

    // 添加CSS压缩方法
    private function minify_css($css) {
        $css = preg_replace('/\s+/', ' ', $css);
        $css = preg_replace('/\/\*[^*]*\*+([^\/][^*]*\*+)*\//', '', $css);
        $css = str_replace(array(': ', ' {', '{ ', ', ', '} ', ';}'), array(':','{','{',',','}',';}'), $css);
        return trim($css);
    }

    /**
     * 默认主题渲染 - jeffer.xyz
     */
    private function render_default_theme($feeds, $atts) {
        $output = '<div class="jefrss-theme jefrss-theme-default">';
        
        // 左侧站点列表
        $output .= '<div class="jefrss-sites-sidebar">';
        $output .= '<h2 class="jefrss-sidebar-title">订阅站点</h2>';
        $output .= '<ul class="jefrss-sites-list">';
        foreach ($feeds as $url => $feed) {
            $output .= sprintf(
                '<li class="jefrss-site-item">
                    <img src="%s" alt="%s" class="jefrss-site-icon" />
                    <span class="jefrss-site-name">%s</span>
                </li>',
                esc_url(jefrss_get_site_icon_url($url)),
                esc_attr($feed['name']),
                esc_html($feed['name'])
            );
        }
        $output .= '</ul>';
        $output .= '</div>';
        
        // 右侧文章列表
        $output .= '<div class="jefrss-articles-content">';
        foreach ($feeds as $url => $feed) {
            foreach ($feed['items'] as $item) {
                $title = mb_strimwidth($item['title'], 0, 60, '...', 'UTF-8');
                $output .= sprintf(
                    '<article class="jefrss-article">
                        <h3 class="jefrss-article-title">
                            <a href="%s" target="_blank" title="%s">%s</a>
                        </h3>
                        <div class="jefrss-article-excerpt">%s</div>
                        <div class="jefrss-article-meta">
                            <span class="jefrss-article-site">%s</span>
                            <span class="jefrss-article-date">%s</span>
                        </div>
                    </article>',
                    esc_url($item['link']),
                    esc_attr($item['title']),
                    esc_html($title),
                    esc_html(wp_trim_words($item['description'], 50)),
                    esc_html($feed['name']),
                    esc_html(human_time_diff(strtotime($item['date']), current_time('timestamp'))) . '前'
                );
            }
        }
        $output .= '</div>';
        
        $output .= '</div>';
        
        // 添加主题样式
        $output .= $this->get_default_theme_styles();
        
        return $output;
    }

    /**
     * 默认主题样式
     */
    private function get_default_theme_styles() {
        return '<style>
        .jefrss-theme-default {
            max-width: 800px;
            margin: 0 auto;
            background: var(--theme-bg);
            border-radius: 8px;
            padding: 20px;
        }
        
        .jefrss-article {
            padding: 25px 0;
            border-bottom: 1px solid var(--theme-border);
        }
        
        .jefrss-article:last-child {
            border-bottom: none;
        }
        
        .jefrss-article-header {
            display: flex;
            align-items: center;
            justify-content: space-between;
            margin-bottom: 8px;
        }
        
        .jefrss-site-info {
            display: flex;
            align-items: center;
            gap: 6px;
        }
        
        .jefrss-site-icon {
            width: 20px;
            height: 20px;
            border-radius: 4px;
        }
        
        .jefrss-site-name {
            font-size: 13px;
            color: var(--theme-light);
        }
        
        .jefrss-article-title {
            margin: 0 0 8px 0;
            font-size: 18px;
            line-height: 1.6;
            font-weight: normal;
            white-space: nowrap;
            overflow: hidden;
            text-overflow: ellipsis;
            color: var(--jefrss-text) !important;
        }
        
        .jefrss-article-title a {
          
            text-decoration: none;
            display: block;
            white-space: nowrap;
            overflow: hidden;
            text-overflow: ellipsis;
            color: var(--jefrss-text) !important;
        }
        
        .jefrss-article-title a:hover {
            color: var(--theme-primary);
        }
        
        .jefrss-article-date {
            font-size: 13px;
            color: var(--theme-light);
        }
        
        .jefrss-article-excerpt {
            color: var(--theme-meta);
            font-size: 17px;
            line-height: 1.6;
            margin: 0;
        }
        
        .jefrss-article-meta {
            margin-bottom: 12px;
            display: flex;
            align-items: center;
            gap: 6px;
        }
        
        @media (max-width: 768px) {
            .jefrss-article {
                padding: 18px 0;
            }
             .jefrss-article-excerpt {
                font-size: 14px;
            .jefrss-article-title {
                font-size: 15px;
            }
        }
        </style>';
    }

    /**
     * 现代主题渲染
     */
    private function render_card_theme($feeds, $atts) {
        $output = '<div class="jefrss-theme jefrss-theme-card">';
        
        $all_articles = array();
        foreach ($feeds as $url => $feed) {
            foreach ($feed['items'] as $item) {
                $all_articles[] = array(
                    'item' => $item,
                    'site_name' => $feed['name'],
                    'site_icon' => jefrss_get_site_icon_url($url),
                    'site_url' => $url
                );
            }
        }
        
        usort($all_articles, function($a, $b) {
            return strtotime($b['item']['date']) - strtotime($a['item']['date']);
        });
        
        $all_articles = array_slice($all_articles, 0, intval($atts['article_count']));
        
        foreach ($all_articles as $article) {
            $output .= sprintf(
                '<article class="jefrss-card">
                    <div class="jefrss-site-info">
                        <img src="%s" alt="%s" class="jefrss-site-icon">
                        <div class="jefrss-site-meta">
                            <div class="jefrss-site-header">
                                <span class="jefrss-site-name">%s 发布了：</span>
                                <a href="%s" class="jefrss-article-title">%s</a>
                            </div>
                            <time class="jefrss-article-date">%s</time>
                            <div class="jefrss-article-excerpt">%s</div>
                        </div>
                    </div>
                </article>',
                esc_url($article['site_icon']),
                esc_attr($article['site_name']),
                esc_html($article['site_name']),
                esc_url($article['item']['link']),
                esc_html($article['item']['title']),
                esc_html(date('Y-m-d H:i:s', strtotime($article['item']['date']))),
                esc_html(wp_trim_words($article['item']['description'], $atts['display_length']))
            );
        }
        
        $output .= '</div>';
        return $output;
    }

    /**
     * 现代主题样式
     */
    private function get_card_theme_styles() {
        return '<style>
        .jefrss-theme-card-wrapper {
            padding: 24px;
            background: var(--theme-bg);
            max-width: 100%;
            overflow-x: hidden; /* 防止水平溢出 */
        }
        
        .jefrss-card {
            border: 1px solid var(--theme-border);
            border-radius: 12px;
            padding: 20px;
            transition: all 0.2s ease;
            margin: 0 0 24px 0 !important; /* 统一外边距 */
            display: block;
            box-sizing: border-box;
            width: 100%; /* 确保卡片宽度不超过容器 */
            overflow: hidden; /* 防止内容溢出 */
        }
        
        .jefrss-site-info {
            display: flex;
            gap: 16px;
            align-items: flex-start;
            width: 100%;
            overflow: hidden; /* 防止内容溢出 */
        }
        
        .jefrss-site-icon-wrapper {
            flex-shrink: 0;
        }
        
        .jefrss-site-icon {
            width: 48px;
            height: 48px;
            border-radius: 8px;
        }
        
        .jefrss-site-content {
            flex: 1;
            min-width: 0; /* 允许flex子项缩小到比内容更小 */
            overflow: hidden; /* 防止内容溢出 */
        }
        
        .jefrss-site-header {
            display: flex;
            align-items: center;
            gap: 6px;
            flex-wrap: wrap;
            margin-bottom: 6px;
            width: 100%;
        }
        
        .jefrss-site-name {
            font-size: 14px;
            font-weight: 500;
            line-height: 1.6;
            white-space: nowrap; /* 站点名称不换行 */
        }
        
        .jefrss-published {
            color: var(--theme-meta);
            font-size: 14px;
            line-height: 1.6;
            white-space: nowrap; /* "发布了："文本不换行 */
        }
        
        .jefrss-article-title {
            color: var(--jefrss-text) !important;
            text-decoration: none;
            font-size: 14px;
            line-height: 1.6;
            display: block;
            overflow: hidden;
            text-overflow: ellipsis;
            white-space: nowrap; /* 标题单行显示并省略 */
            width: 100%;
        }
        
        .jefrss-article-title:hover {
            color: var(--theme-primary);
        }
        
        .jefrss-article-date {
            color: var(--theme-light);
            display: block;
            font-size: 12px;
            margin: 6px 0;
            line-height: 1.4;
        }
        
        .jefrss-article-excerpt {
            color: var(--theme-meta);
            font-size: 14px;
            line-height: 1.6;
            display: -webkit-box;
            -webkit-line-clamp: 2;
            -webkit-box-orient: vertical;
            overflow: hidden;
            margin-top: 8px;
            word-break: break-word; /* 允许长单词断行 */
        }
        
        @media (max-width: 768px) {
            .jefrss-theme-card-wrapper {
                padding: 0px; /* 减小移动端padding */
            }
            
            .jefrss-card {
                padding: 16px;
                margin-bottom: 16px !important;
            }
            
            .jefrss-site-icon {
                width: 40px;
                height: 40px;
            }
            
            .jefrss-site-header {
                gap: 4px; /* 减小移动端间距 */
            }
            
            .jefrss-article-excerpt {
                font-size: 13px;
                -webkit-line-clamp: 2; /* 限制移动端摘要行数 */
            }
        }
        </style>';
    }

    /**
     * 时间线主题渲染 - my1981.cn
     */
    private function render_timeline_theme($feeds, $atts) {
        $output = '<div class="jefrss-theme jefrss-theme-timeline">';
        
        // 合并所有文章并按时间排序
        $all_articles = array();
        foreach ($feeds as $url => $data) {
            $feed = $data['feed'];
            foreach ($feed['items'] as $item) {
                $all_articles[] = array(
                    'item' => $item,
                    'site_name' => $feed['name'],
                    'site_icon' => jefrss_get_site_icon_url(parse_url($url, PHP_URL_HOST)),
                    'site_url' => $url
                );
            }
        }
        
        // 按时间排序
        usort($all_articles, function($a, $b) {
            return strtotime($b['item']['date']) - strtotime($a['item']['date']);
        });
        
        // 限制文章数量
        $all_articles = array_slice($all_articles, 0, intval($atts['article_count']));
        
        foreach ($all_articles as $article) {
            $output .= sprintf(
                '<article class="jefrss-timeline-item">
                    <div class="jefrss-timeline-meta">
                        <time class="jefrss-timeline-date">%s</time>
                        <div class="jefrss-timeline-dot"></div>
                    </div>
                    <div class="jefrss-timeline-content">
                        <div class="jefrss-site-info">
                            <img src="%s" alt="%s" class="jefrss-site-icon" />
                            <span class="jefrss-site-name">%s</span>
                        </div>
                        <h3 class="jefrss-article-title">
                            <a href="%s" target="_blank" title="%s">%s</a>
                        </h3>
                        <div class="jefrss-article-excerpt">%s</div>
                    </div>
                </article>',
                esc_html(date('Y-m-d', strtotime($article['item']['date']))),
                esc_url($article['site_icon']),
                esc_attr($article['site_name']),
                esc_html($article['site_name']),
                esc_url($article['item']['link']),
                esc_attr($article['item']['title']),
                esc_html(mb_strimwidth($article['item']['title'], 0, 60, '...', 'UTF-8')),
                esc_html(wp_trim_words($article['item']['description'], $atts['display_length']))
            );
        }
        
        $output .= '</div>';
        $output .= $this->get_timeline_theme_styles();
        return $output;
    }

    /**
     * 时间线主题样式 - 参考 https://my1981.cn/friends.html
     */
    private function get_timeline_theme_styles() {
        return '<style>
        .jefrss-theme-timeline {
            --dot-size: 10px;
            --dot-border: 2px;
            
            max-width: 800px;
            margin: 0 auto;
            padding: 40px 20px;
            position: relative;
            overflow-x: hidden; /* 添加横向溢出控制 */
        }
        
        .jefrss-theme-timeline::before {
            content: "";
            position: absolute;
            left: 120px;
            top: 0;
            bottom: 0;
            width: var(--timeline-width);
            background: var(--theme-border);
        }
        
        .jefrss-timeline-item {
            display: grid;
            grid-template-columns: 120px 1fr;
            gap: 20px;
            margin-bottom: 30px;
            position: relative;
            background: #ffffff00;
            border-color: var(--theme-border);
        }
        
        .jefrss-timeline-meta {
            text-align: right;
            padding-right: 20px;
            position: relative;
        }
        
        .jefrss-timeline-date {
            color: var(--theme-light);
            font-size: 14px;
            font-weight: 500;
        }
        
        .jefrss-timeline-dot {
            position: absolute;
            right: -6px;
            top: 50%;
            width: var(--dot-size);
            height: var(--dot-size);
            background: var(--theme-border);
            border: var(--dot-border) solid var(--theme-primary);
            border-radius: 50%;
            transform: translateY(-50%);
            transition: all 0.2s ease;
        }
        
        .jefrss-timeline-item:hover .jefrss-timeline-dot {
            background: var(--theme-primary);
            transform: translateY(-50%) scale(1.2);
        }
        
        .jefrss-timeline-content {
            flex: 1;
            padding: 15px;
            background: #2c2b2b00;
            border-radius: 8px;
            border: 1px solid var(--theme-border);
            overflow: hidden; /* 添加内容溢出控制 */
            width: 100%; /* 确保内容区域不超过容器 */
            box-sizing: border-box; /* 添加盒模型控制 */
        }
        
        .jefrss-article-title {
            margin: 10px 0;
            font-size: 15px;
            line-height: 1.6;
            white-space: nowrap;
            overflow: hidden;
            text-overflow: ellipsis;
            max-width: 100%;
            width: 100%; /* 确保宽度不超过容器 */
        }
        
        .jefrss-article-title a {
            color: var(--jefrss-text) !important;
            text-decoration: none;
            display: block;
            white-space: nowrap;
            overflow: hidden;
            text-overflow: ellipsis;
            width: 100%; /* 确保链接宽度不超过容器 */
        }
        
        .jefrss-article-excerpt {
            margin-top: 10px;
            font-size: 14px;
            line-height: 1.6;
            color: var(--theme-meta);
            opacity: 0.9;
            overflow: hidden; /* 添加溢出控制 */
            text-overflow: ellipsis; /* 添加文本溢出处理 */
            display: -webkit-box;
            -webkit-line-clamp: 2; /* 限制为两行 */
            -webkit-box-orient: vertical;
            word-break: break-word; /* 允许长单词断行 */
        }
        
        @media (max-width: 768px) {
            .jefrss-timeline-item {
                grid-template-columns: 1fr;
            }
            
            .jefrss-timeline-meta {
                text-align: left;
                padding-right: 0;
                padding-left: 20px;
            }
            
            .jefrss-timeline-dot {
                left: -6px;
                right: auto;
            }
            
            .jefrss-theme-timeline::before {
                left: 0;
            }
        }
        </style>';
    }

    /**
     * 杂志主题渲染 - evan.xin
     */
    private function render_grid_theme($feeds, $atts) {
        $output = '<div class="jefrss-theme jefrss-theme-grid">';
        
        // 合并所有文章
        $all_articles = array();
        foreach ($feeds as $url => $feed) {
            foreach ($feed['items'] as $item) {
                $item['site_name'] = $feed['name'];
                $item['site_icon'] = jefrss_get_site_icon_url($url);
                $item['site_url'] = $url;
                $all_articles[] = $item;
            }
        }
        
        // 按时间排序
        usort($all_articles, function($a, $b) {
            return strtotime($b['date']) - strtotime($a['date']);
        });
        
        // 限制显示数量
        $all_articles = array_slice($all_articles, 0, $atts['article_count']);
        
        foreach ($all_articles as $article) {
            $output .= sprintf(
                '<article class="jefrss-grid-item">
                    <div class="jefrss-grid-header">
                        <img src="%s" alt="%s" class="jefrss-site-icon" />
                        <div class="jefrss-site-info">
                            <span class="jefrss-site-name">%s</span>
                            <time class="jefrss-article-date">%s</time>
                        </div>
                    </div>
                    <div class="jefrss-grid-content">
                        <h3 class="jefrss-article-title">
                            <a href="%s" target="_blank">%s</a>
                        </h3>
                        <div class="jefrss-article-excerpt">%s</div>
                    </div>
                </article>',
                esc_url($article['site_icon']),
                esc_attr($article['site_name']),
                esc_html($article['site_name']),
                esc_html(human_time_diff(strtotime($article['date']), current_time('timestamp'))) . '前',
                esc_url($article['link']),
                esc_html($article['title']),
                esc_html(wp_trim_words($article['description'], $atts['display_length']))
            );
        }
        
        $output .= '</div>';
        $output .= $this->get_grid_theme_styles();
        return $output;
    }

    /**
     * 杂志主题样式 - 参考 https://www.evan.xin/you/
     */
    private function get_grid_theme_styles() {
        return '<style>
        .jefrss-theme-grid {
            max-width: 800px;
            margin: 0 auto;
            padding: 20px;
        }
        
        .jefrss-site-block {
            display: flex;
            gap: 20px;
            padding: 20px 0;
            border-bottom: 1px solid var(--theme-border);
        }
        
        .jefrss-site-icon-wrapper {
            flex-shrink: 0;
        }
        
        .jefrss-site-icon {
            width: 48px;
            height: 48px;
            border-radius: 6px;
        }
        
        .jefrss-site-articles {
            flex: 1;
        }
        
        .jefrss-article-item {
            margin-bottom: 15px;
        }
        
        .jefrss-article-item:last-child {
            margin-bottom: 0;
        }
        
        .jefrss-article-title {
        color: var(--jefrss-text) !important;
            margin: 0 0 6px;
            font-size: 16px;
            line-height: 1.6;
            font-weight: normal;
        }
        
        .jefrss-article-title a {
           
            text-decoration: none;
        }
        
        .jefrss-article-title a:hover {
            color: var(--theme-primary);
        }
        
        .jefrss-article-date {
            font-size: 14px;
            color: #999;
        }
        
        @media (max-width: 768px) {
            .jefrss-theme-grid {
                padding: 0px;
            }
            
            .jefrss-site-block {
                padding: 15px 0;
            }
            
            .jefrss-site-icon {
                width: 40px;
                height: 40px;
            }
        }
        
        @media (prefers-color-scheme: dark) {
            .jefrss-theme-grid {
                background: var(--jefrss-bg);
            }
            
            .jefrss-site-block {
                background: var(--jefrss-card-bg);
                border-color: var(--jefrss-border);
            }
            
            .jefrss-site-name {
                color: var(--jefrss-text) !important;
            }
            
            .jefrss-article-title a {
                color: var(--jefrss-text) !important;
            }
            
            .jefrss-article-title a:hover {
                color: var(--jefrss-link-hover) !important;
            }
            
            .jefrss-article-date {
                color: var(--jefrss-subtle);
            }
        }
        </style>';
    }

    /**
     * 网格主题渲染 - liushen.fun
     */
    private function render_magazine_theme($feeds, $atts) {
        $output = '<div class="jefrss-theme-wrapper">';
        $output .= '<div class="jefrss-theme jefrss-theme-magazine">';
        
        // 合并所有文章并按时间排序
        $all_articles = array();
        foreach ($feeds as $url => $feed) {
            foreach ($feed['items'] as $item) {
                $item['site_name'] = $feed['name'];
                $item['site_icon'] = jefrss_get_site_icon_url($url);
                $item['site_url'] = $url;
                $all_articles[] = $item;
            }
        }
        
        usort($all_articles, function($a, $b) {
            return strtotime($b['date']) - strtotime($a['date']);
        });
        
        $all_articles = array_slice($all_articles, 0, $atts['article_count']);
        
        // 分成两列显示
        $columns = array_chunk($all_articles, ceil(count($all_articles) / 2));
        
        $output .= '<div class="jefrss-magazine-columns">';
        foreach ($columns as $column) {
            $output .= '<div class="jefrss-magazine-column">';
            foreach ($column as $article) {
                $output .= sprintf(
                    '<article class="jefrss-magazine-item">
                        <div class="jefrss-magazine-header">
                            <div class="jefrss-site-info">
                                <img src="%s" alt="%s" class="jefrss-site-icon" />
                                <span class="jefrss-site-name">%s</span>
                            </div>
                            <time class="jefrss-article-date">%s</time>
                        </div>
                        <h3 class="jefrss-article-title">
                            <a href="%s" target="_blank">%s</a>
                        </h3>
                        <div class="jefrss-article-excerpt">%s</div>
                    </article>',
                    esc_url($article['site_icon']),
                    esc_attr($article['site_name']),
                    esc_html($article['site_name']),
                    esc_html(human_time_diff(strtotime($article['date']), current_time('timestamp'))) . '前',
                    esc_url($article['link']),
                    esc_html($article['title']),
                    esc_html(wp_trim_words($article['description'], $atts['display_length']))
                );
            }
            $output .= '</div>';
        }
        $output .= '</div>';
        
        $output .= '</div>';
        $output .= $this->get_magazine_theme_styles();
        $output .= '</div>';
        return $output;
    }

    /**
     * 网格主题样式 - 参考 https://blog.liushen.fun/fcircle/
     */
    private function get_magazine_theme_styles() {
        return '<style>
        /* 添加包装容器样式 */
        .jefrss-theme-wrapper {
            width: 100%;
            max-width: 1200px;
            margin: 0 auto;
            overflow: hidden;
        }

        .jefrss-theme-magazine {
            width: 100%;
            display: flex;
            flex-wrap: wrap;
            margin: -10px;
        }
        
        .jefrss-magazine-item {
            position: relative;
            display: flex;
            flex-direction: column;
            justify-content: space-between;
            padding: 20px;
            background: #2c2b2b00;
            border-radius: 12px;
            transition: all 0.2s ease;
            border: 1px solid var(--theme-border);
            min-height: 160px;
            /* 使用百分比宽度 */
            width: calc(33.33% - 20px);
            margin: 10px;
            box-sizing: border-box;
            /* 防止内容溢出 */
            overflow: hidden;
        }
        
        .jefrss-magazine-item:nth-child(3n) {
            margin-right: 0;
        }
        
        .jefrss-magazine-content {
            position: relative;
            z-index: 2;
            display: flex;
            flex-direction: column;
            height: 100%;
        }
        
        .jefrss-article-title {
            margin: 0;
            font-size: 16px;
            line-height: 1.6;
            font-weight: normal;
            flex: 1;
            width: 100% !important;
            color: var(--jefrss-text) !important;
        }
        
        .jefrss-article-title a {
            color: var(--jefrss-text) !important;
            text-decoration: none;
            display: block;
            width: 100%;
        }
        
        .jefrss-magazine-footer {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-top: 15px;
            width: 100% !important;
        }
        
        .jefrss-site-info {
            display: flex;
            align-items: center;
            gap: 8px;
        }
        
        .jefrss-site-icon {
            width: 20px;
            height: 20px;
            border-radius: 4px;
        }
        
        .jefrss-site-name {
            font-size: 14px;
            color: #666;
        }
        
        .jefrss-article-date {
            font-size: 13px;
            color: #999;
        }
        
        .jefrss-magazine-bg {
            position: absolute;
            right: -20px;
            bottom: -20px;
            width: 100px;
            height: 100px;
            opacity: 0.1;
            z-index: 1;
            background-size: contain;
            background-repeat: no-repeat;
            background-position: center;
            /* 添加圆形效果 */
            border-radius: 50%;
            overflow: hidden;
            /* 稍微调整位置和大小 */
            width: 80px;
            height: 80px;
            right: -10px;
            bottom: -10px;
        }
        
        @media (max-width: 1024px) {
            .jefrss-magazine-item {
                width: calc((100% - 20px) / 2);
            }
            
            .jefrss-magazine-item:nth-child(3n) {
                margin-right: auto;
            }
            
            .jefrss-magazine-item:nth-child(2n) {
                margin-right: 0;
            }
        }
        
        @media (max-width: 640px) {
            .jefrss-magazine-item {
                padding: 15px;
                min-height: 140px;
                width: 100%;
                margin-right: 0;
            }
        }
        </style>';
    }

    /**
     * 极简主题渲染 - feng.pub
     */
    private function render_minimal_theme($feeds, $atts) {
        $output = '<div class="jefrss-theme jefrss-theme-minimal">';
        
        // 先按站点最新文章排序
        $sorted_feeds = array();
        foreach ($feeds as $url => $feed) {
            if (!empty($feed['items'])) {
                $latest_date = strtotime($feed['items'][0]['date']);
                $sorted_feeds[$url] = array(
                    'feed' => $feed,
                    'latest_date' => $latest_date
                );
            }
        }
        
        uasort($sorted_feeds, function($a, $b) {
            return $b['latest_date'] - $a['latest_date'];
        });

        // 合并所有文章并按时间排序
        $all_articles = array();
        foreach ($sorted_feeds as $url => $data) {
            $feed = $data['feed'];
            foreach ($feed['items'] as $item) {
                $item['site_name'] = $feed['name'];
                $item['site_icon'] = jefrss_get_site_icon_url($url);
                $item['site_url'] = $url;
                $all_articles[] = $item;
            }
        }
        
        usort($all_articles, function($a, $b) {
            return strtotime($b['date']) - strtotime($a['date']);
        });
        
        $all_articles = array_slice($all_articles, 0, $atts['article_count']);
        
        foreach ($all_articles as $article) {
            $output .= sprintf(
                '<article class="jefrss-minimal-item">
                    <div class="jefrss-minimal-header">
                        <h3 class="jefrss-article-title">
                            <a href="%s" target="_blank">%s</a>
                        </h3>
                        <div class="jefrss-article-meta">
                            <time class="jefrss-article-date">%s</time>
                            <span class="jefrss-site-name">%s</span>
                        </div>
                    </div>
                    <div class="jefrss-article-excerpt">%s</div>
                </article>',
                esc_url($article['link']),
                esc_html($article['title']),
                esc_html(date('Y-m-d', strtotime($article['date']))),
                esc_html($article['site_name']),
                esc_html(wp_trim_words($article['description'], 100))
            );
        }

        $output .= '</div>';
        $output .= $this->get_minimal_theme_styles();
        return $output;
    }

    /**
     * 极简主题样式
     */
    private function get_minimal_theme_styles() {
        return '<style>
        .jefrss-theme-minimal {
            --theme-primary: #00b894;
            --theme-text: #2c3e50;
            --theme-bg: #f5f6fa;
            --theme-card-bg: #ffffff;
            --theme-border: #edf2f7;
            --theme-meta: #718096;
            --theme-excerpt: #4a5568;
            
            max-width: 800px;
            margin: 0 auto;
            padding: 15px;
            background: var(--theme-bg);
        }

        .jefrss-minimal-item {
            margin-bottom: 20px;
            position: relative;
         
            border-radius: 12px;
            padding: 15px;
            border: 1px solid var(--theme-border);
            transition: all 0.2s ease;
            box-shadow: 0 2px 4px rgba(0,0,0,0.05);
        }
        
        .jefrss-minimal-item:hover {
            transform: translateY(-2px);
            box-shadow: 0 4px 12px rgba(0,0,0,0.1);
        }

        .jefrss-minimal-header {
            margin-bottom: 10px;
        }

        .jefrss-article-title {
            margin: 0 0 6px 0;
            font-size: 16px;
            line-height: 1.6;
            display: block;
        }

        .jefrss-article-title a {
            color: var(--jefrss-text) !important;
            text-decoration: none;
            font-weight: 500;
            display: block;
        }
        
        .jefrss-article-title a:hover {
            color: var(--theme-primary);
        }
        
        .jefrss-article-meta {
            display: flex;
            align-items: center;
            gap: 12px;
            color: var(--theme-meta);
            font-size: 14px;
        }
        
        .jefrss-article-excerpt {
            color: var(--theme-excerpt);
            font-size: 14px;
            line-height: 1.6;
            margin-top: 8px;
            opacity: 0.85;
        }
        
        .jefrss-article-date {
            font-size: 14px;
            color: var(--theme-meta);
        }
        
        .jefrss-site-name {
            font-size: 14px;
            color: var(--theme-meta);
        }

        @media (prefers-color-scheme: dark) {
            .jefrss-theme-minimal {
                --theme-text: #e2e8f0;
                --theme-bg: #1a202c;
                --theme-card-bg: #2d3748;
                --theme-border: #4a5568;
                --theme-meta: #a0aec0;
                --theme-excerpt: #cbd5e0;
            }
        }

        @media (max-width: 768px) {
            .jefrss-theme-minimal {
                padding: 0px;
            }
            
            .jefrss-minimal-item {
                padding: 8px;
                margin-bottom: 15px;
            }
            
            .jefrss-article-title {
                font-size: 15px;
            }
            
            .jefrss-article-excerpt {
            color: var(--theme-meta);
                font-size: 13px;
            }
        }
        </style>';
    }
}

// 初始化主题管理器
$GLOBALS['jefrss_theme_manager'] = Jefrss_Theme_Manager::get_instance();

// 在页面头部注入主题样式
add_action('wp_head', array($GLOBALS['jefrss_theme_manager'], 'inject_theme_styles')); 